@@ -71,6 +71,7 @@ namespace GAGGUI
 		TEXT_VALIDATED,
 		TEXT_CANCELED,
 		TEXT_SET,
+		TEXT_TABBED,
 	
 		LIST_ELEMENT_SELECTED,
 	
@@ -79,6 +80,7 @@ namespace GAGGUI
 		VALUE_CHANGED,
 		
 		KEY_CHANGED,
+		
 	};
 	
 	class Screen;
@@ -154,6 +156,7 @@ namespace GAGGUI
 		virtual bool isOnWidget(int x, int y) = 0;
 	protected:
 		friend class Screen;
+		friend class Panel;
 		Screen *parent;
 		/*! Called when an SDL_MOUSEMOTION event occurs.
 		 * As timertick, this is a template method,
@@ -231,9 +234,18 @@ namespace GAGGUI
 		//! \copydoc Widget::isOnWidget
 		virtual bool isOnWidget(int x, int y);
 		
+		//! Returns width of widget
+		Sint32 getLeft() const { return x; }
+		
+		//! Returns width of widget
+		Sint32 getTop() const { return y; }
+		
 		//! Returns width of widget
 		Sint32 getWidth() const { return w; }
 		
+		//! Returns width of widget
+		Sint32 getHeight() const { return h; }
+		
 		//! Sets the screen position
 		virtual void setScreenPosition(int nx, int ny) { x = nx; y = ny; }
 	
