@@ -35,13 +35,16 @@ namespace GAGGUI
 	{
 	protected:
 		Uint16 unicodeShortcut;
+		bool isClickable;
 		
 	public:
-		Button() {  }
+		Button() { isClickable=true; }
 		Button(int x, int y, int w, int h, Uint32 hAlign, Uint32 vAlign, int returnCode, Uint16 unicodeShortcut=0);
 		Button(int x, int y, int w, int h, Uint32 hAlign, Uint32 vAlign, int returnCode, const std::string& tooltip, const std::string &font, Uint16 unicodeShortcut=0);
 		virtual ~Button() { }
 	
+		//! Makes it so that nothing occurs on click
+		virtual void setClickable(bool enabled) { isClickable = enabled; }
 	protected:
 		virtual void onSDLKeyDown(SDL_Event *event);
 		virtual void onSDLMouseButtonDown(SDL_Event *event);
@@ -74,9 +77,9 @@ namespace GAGGUI
 	{
 	protected:
 		bool state;
-	
+		bool isClickable;
 	public:
-		OnOffButton() { state=false; returnCode=0; }
+		OnOffButton() { state=false; returnCode=0; isClickable=true;}
 		OnOffButton(const std::string &tooltip, const std::string &tooltipFont) :HighlightableWidget(tooltip, tooltipFont) { state=false; returnCode=0; }
 		OnOffButton(int x, int y, int w, int h, Uint32 hAlign, Uint32 vAlign, bool startState, int returnCode);
 		OnOffButton(int x, int y, int w, int h, Uint32 hAlign, Uint32 vAlign, bool startState, int returnCode, const std::string &tooltip, const std::string &tooltipFont);
@@ -85,6 +88,33 @@ namespace GAGGUI
 		virtual void paint(void);
 		virtual bool getState(void) { return state; }
 		virtual void setState(bool newState);
+	
+		//! Makes it so that nothing occurs on click
+		virtual void setClickable(bool enabled) { isClickable = enabled; }
+	protected:
+		virtual void onSDLMouseButtonDown(SDL_Event *event);
+		virtual void onSDLMouseButtonUp(SDL_Event *event);
+	};
+	
+	///A button like OnOffButton except that it has 3 states, off (0), on (1) and alternate (2)
+	class TriButton:public HighlightableWidget
+	{
+	protected:
+		Uint8 state;
+		bool isClickable;
+	public:
+		TriButton() { state=false; returnCode=0; isClickable=true;}
+		TriButton(const std::string &tooltip, const std::string &tooltipFont) :HighlightableWidget(tooltip, tooltipFont) { state=0; returnCode=0; }
+		TriButton(int x, int y, int w, int h, Uint32 hAlign, Uint32 vAlign, Uint8 startState, int returnCode);
+		TriButton(int x, int y, int w, int h, Uint32 hAlign, Uint32 vAlign, Uint8 startState, int returnCode, const std::string &tooltip, const std::string &tooltipFont);
+		virtual ~TriButton() { }
+	
+		virtual void paint(void);
+		virtual Uint8 getState(void) { return state; }
+		virtual void setState(Uint8 newState);
+	
+		//! Makes it so that nothing occurs on click
+		virtual void setClickable(bool enabled) { isClickable = enabled; }
 	protected:
 		virtual void onSDLMouseButtonDown(SDL_Event *event);
 		virtual void onSDLMouseButtonUp(SDL_Event *event);
@@ -99,7 +129,7 @@ namespace GAGGUI
 		bool isClickable;
 	
 	public:
-		ColorButton() { selColor=returnCode=0; isClickable=true; }
+		ColorButton() { selColor=returnCode=0; isClickable=true;}
 		//! ColorButton constructor
 		ColorButton(int x, int y, int w, int h, Uint32 hAlign, Uint32 vAlign, int returnCode);
 		//! With a tooltip
