@@ -4,7 +4,7 @@
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
+  the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.
 
   This program is distributed in the hope that it will be useful,
@@ -39,13 +39,15 @@ namespace GAGGUI
 		bool dragging;
 		Sint32 id;
 		std::string sprite;
+		bool taper;
+	
 	
 		//! cache, recomputed on internalInit
 		GAGCore::Sprite *archPtr;
 	
 	public:
-		Selector(int x, int y, Uint32 hAlign, Uint32 vAlign, unsigned width, unsigned defaultValue=0, unsigned maxValue=16, unsigned step=1, const char *sprite=NULL, Sint32 id=-1);
-		Selector(int x, int y, Uint32 hAlign, Uint32 vAlign, unsigned width, const std::string& tooltip, const std::string &tooltipFont, unsigned defaultValue=0, unsigned maxValue=16, unsigned step=1, const char *sprite=NULL, Sint32 id=-1);
+		Selector(int x, int y, Uint32 hAlign, Uint32 vAlign, unsigned width, unsigned defaultValue=0, unsigned maxValue=16, bool taper=false, unsigned step=1, const char *sprite=NULL, Sint32 id=-1);
+		Selector(int x, int y, Uint32 hAlign, Uint32 vAlign, unsigned width, const std::string& tooltip, const std::string &tooltipFont, unsigned defaultValue=0, unsigned maxValue=16, bool taper=false, unsigned step=1, const char *sprite=NULL, Sint32 id=-1);
 		virtual ~Selector() { }
 	
 		virtual void internalInit(void);
