@@ -234,7 +234,13 @@ namespace GAGGUI
 					parent->onAction(this, TEXT_CANCELED, 0, 0);
 				}
 				break;
-				
+			
+				case SDLK_TAB:
+				{
+					parent->onAction(this, TEXT_TABBED, 0, 0);
+				}
+				break;
+					
 				default:
 				{
 					Uint16 c=event->key.keysym.unicode;
