@@ -25,7 +25,9 @@
 #include <iostream>
 #include <cctype>
 
+#ifndef YOG_SERVER_ONLY
 #include <SDLGraphicContext.h>
+#endif
 
 namespace GAGCore
 {
@@ -234,6 +236,8 @@ namespace GAGCore
 			languageCodes[getStringInLang("[language-code]", i)] = i;
 		}
 		
+		defaultLang = getLangCode("en");
+		
 		return true;
 	}
 	
@@ -259,8 +263,10 @@ namespace GAGCore
 			if (accessIt == stringAccess.end())
 			{
 				std::cerr << "StringTable::getString(\"" << stringname << ", " << index << "\") : error, no such key." << std::endl;
+				#ifndef YOG_SERVER_ONLY
 				if(!GAGCore::DrawableSurface::translationPicturesDirectory.empty() && GAGCore::DrawableSurface::wroteTexts.find(std::string(stringname))==GAGCore::DrawableSurface::wroteTexts.end())
 					GAGCore::DrawableSurface::texts[std::string(stringname)]=key;
+			    #endif
 				return stringname;
 			}
 			else
@@ -274,14 +280,18 @@ namespace GAGCore
 				std::string &s = strings[accessIt->second+dec]->data[actLang];
 				if (s.length() == 0)
 				{
+					#ifndef YOG_SERVER_ONLY
 					if(!GAGCore::DrawableSurface::translationPicturesDirectory.empty() && GAGCore::DrawableSurface::wroteTexts.find(std::string(stringname))==GAGCore::DrawableSurface::wroteTexts.end())
 						GAGCore::DrawableSurface::texts[strings[accessIt->second+dec]->data[defaultLang]]=key;
+					#endif
 					return strings[accessIt->second+dec]->data[defaultLang].c_str();
 				}
 				else
 				{
+					#ifndef YOG_SERVER_ONLY
 					if(!GAGCore::DrawableSurface::translationPicturesDirectory.empty() && GAGCore::DrawableSurface::wroteTexts.find(std::string(stringname))==GAGCore::DrawableSurface::wroteTexts.end())
 						GAGCore::DrawableSurface::texts[s]=key;
+					#endif
 					return s.c_str();
 				}
 			}
