@@ -4,7 +4,7 @@
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
+  the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.
 
   This program is distributed in the hope that it will be useful,
@@ -26,6 +26,8 @@
 #include <Types.h>
 #endif
 
+#include <boost/shared_ptr.hpp>
+
 namespace GAGCore
 {
 	class InputStream;
@@ -69,7 +71,9 @@ public:
 	bool load(GAGCore::InputStream *stream, Sint32 versionMinor);
 	void save(GAGCore::OutputStream *stream);
 	
-	Order *getOrder(bool paused);
+	static std::string getAIText(int id);
+	
+	boost::shared_ptr<Order> getOrder(bool paused);
 	
 	Uint32 step;
 };
