@@ -2070,19 +2070,21 @@ void NewNicowar::compute_defense_flag_positioning(AIEcho::Echo& echo)
 	for(int i=0; i<1024; ++i)
 	{
 		Unit* unit = echo.player->team->myUnits[i];
-		if(unit && unit->underAttackTimer && unit->movement != Unit::MOV_ATTACKING_TARGET && unit->typeNum != EXPLORER)
+		if(unit && unit->underAttackTimer && unit->movement != Unit::MOV_ATTACKING_TARGET && unit->typeNum != EXPLORER && unitGID[(unit->posX+w)%w * h + (unit->posY+h)%h] == NOGUID)
 		{
-			unitGID[unit->posX * h + unit->posY] = unit->gid;
-			modify_points(counts, w, h, unit->posX, unit->posY, 4, 1, locations);
+			unitGID[(unit->posX+w)%w * h + (unit->posY+h)%h] = unit->gid;
+			modify_points(counts, w, h, (unit->posX+w)%w, (unit->posY+h)%h, 4, 1, locations);
 		}
 	}
 	for(int i=0; i<1024; ++i)
 	{
 		Building* building = echo.player->team->myBuildings[i];
-		if(building && building->underAttackTimer)
+		if(building && building->underAttackTimer && buildingGID[building->posX * h + building->posY] == NOGBID)
 		{
+			int nx = (building->posX - building->type->decLeft + w) %w;
+			int ny = (building->posY - building->type->decTop + h) %h;
 			buildingGID[building->posX * h + building->posY] = building->gid;
-			modify_points(counts, w, h, building->posX, building->posY, 4, 1, locations);
+			modify_points(counts, w, h, nx, ny, 4, 1, locations);
 		}
 	}
 	
@@ -2126,13 +2128,15 @@ void NewNicowar::compute_defense_flag_positioning(AIEcho::Echo& echo)
 				if(unitGID[nx * h + ny] != NOGUID)
 				{
 					Unit* unit = echo.player->team->myUnits[Unit::GIDtoID(unitGID[nx * h + ny])];
-					modify_points(counts, w, h, unit->posX, unit->posY, 4, -1, locations);
+					modify_points(counts, w, h, (unit->posX+w)%w, (unit->posY+h)%h, 4, -1, locations);
 					unitGID[nx * h + ny] = NOGUID;
 				}
 				if(buildingGID[nx * h + ny] != NOGBID)
 				{
 					Building* building = echo.player->team->myBuildings[Building::GIDtoID(buildingGID[nx * h + ny])];
-					modify_points(counts, w, h, building->posX, building->posY, 4, -1, locations);
+					int nx2 = (building->posX - building->type->decLeft + w) %w;
+					int ny2 = (building->posY - building->type->decTop + h) %h;
+					modify_points(counts, w, h, nx2, ny2, 4, -1, locations);
 					buildingGID[nx * h + ny] = NOGBID;
 				}
 				
@@ -2149,6 +2153,21 @@ void NewNicowar::compute_defense_flag_positioning(AIEcho::Echo& echo)
 		}
 		enemyUnits.push_back(std::min(20, enemy_count));
 	}
+	
+	//Remove all flags with an enemy_count of 0
+	for(std::vector<int>::iterator i=flagLocations.begin(); i!=flagLocations.end();)
+	{
+		int n = i-flagLocations.begin();
+		if(enemyUnits[n] == 0)
+		{
+			i = flagLocations.erase(i);
+			enemyUnits.erase(enemyUnits.begin() + n);
+		}
+		else
+		{
+			++i;
+		}
+	}
 
 	//Take all existing defense flags, and move them to the nearest new flag position
 	std::vector<int> existing_defense_flags(defense_flags);
@@ -2213,8 +2232,38 @@ void NewNicowar::compute_defense_flag_positioning(AIEcho::Echo& echo)
 	{
 		if(echo.get_building_register().is_building_found(*i))
 		{
-			ManagementOrder* mo_destroyed=new DestroyBuilding(*i);
-			echo.add_management_order(mo_destroyed);
+		    Building* b = echo.get_building_register().get_building(*i);
+		    int enemy_count = 0;
+		    for(int px = -3; px <= 3; ++px)
+		    {
+				int nx = (b->posX + px + w)%w;
+				for(int py = -3; py<=3; ++py)
+				{
+						int ny = (b->posY + py + h)%h;
+						Uint16 guid = echo.player->map->getGroundUnit(nx, ny);
+						if(guid != NOGUID && (1<<Unit::GIDtoTeam(guid)) & echo.player->team->enemies)
+						{
+								Unit* unit = echo.player->game->teams[Unit::GIDtoTeam(guid)]->myUnits[Unit::GIDtoID(guid)];
+								if(unit->typeNum == WARRIOR)
+								{
+										enemy_count += 1;
+								}
+						}
+				}
+		    }
+		    if(enemy_count == 0)
+		    {
+		            ManagementOrder* mo_destroyed=new DestroyBuilding(*i);
+		            echo.add_management_order(mo_destroyed);
+		    }
+		    else
+		    {
+		            if(enemy_count != echo.get_building_register().get_assigned(*i))
+		            {
+		                    ManagementOrder* mo_assign=new AssignWorkers(std::min(20, enemy_count), *i);
+		                    echo.add_management_order(mo_assign);
+		            }
+		    }
 		}
 	}
 	
