@@ -4,7 +4,7 @@
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
+  the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.
 
   This program is distributed in the hope that it will be useful,
@@ -20,7 +20,7 @@
 #include "AINull.h"
 #include "Order.h"
 
-Order *AINull::getOrder(void)
+boost::shared_ptr<Order> AINull::getOrder(void)
 {
-	return new NullOrder();
+	return boost::shared_ptr<Order>(new NullOrder());
 }
