@@ -4,7 +4,7 @@
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
+  the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.
 
   This program is distributed in the hope that it will be useful,
@@ -33,7 +33,7 @@ public:
 	bool load(GAGCore::InputStream *stream, Player *player, Sint32 versionMinor) { return true; }
 	void save(GAGCore::OutputStream *stream) { }
 	
-	Order *getOrder(void);
+	boost::shared_ptr<Order> getOrder(void);
 	
 private:
 };
