@@ -143,7 +143,7 @@ void Game::clearGame()
 		}
 	}
 
-	///Clears prestige	
+	///Clears prestige
 	totalPrestige=0;
 	totalPrestigeReached=false;
 	isGameEnded=false;
@@ -152,6 +152,9 @@ void Game::clearGame()
 	mouseUnit = NULL;
 	selectedUnit = NULL;
 	selectedBuilding = NULL;
+	
+	hilightBuildingType=0;
+	hilightUnitType=0;
 }
 
 
@@ -167,7 +170,7 @@ void Game::setMapHeader(const MapHeader& newMapHeader)
 
 
 
-void Game::setGameHeader(const GameHeader& newGameHeader)
+void Game::setGameHeader(const GameHeader& newGameHeader, bool saveAI)
 {
 	for (int i=0; i<mapHeader.getNumberOfTeams(); ++i)
 	{
@@ -178,7 +181,7 @@ void Game::setGameHeader(const GameHeader& newGameHeader)
 	for (int i=0; i<newGameHeader.getNumberOfPlayers(); i++)
 	{
 		//Don't change AI's
-		if(gameHeader.getBasePlayer(i).type < BasePlayer::P_AI)
+		if(!saveAI || gameHeader.getBasePlayer(i).type < BasePlayer::P_AI)
 		{
 			delete players[i];
 			players[i]=new Player();
@@ -190,6 +193,9 @@ void Game::setGameHeader(const GameHeader& newGameHeader)
 
 	setSyncRandSeed(newGameHeader.getRandomSeed());
 
+	if(newGameHeader.isMapDiscovered())
+		map.setMapDiscovered();
+
 	gameHeader = newGameHeader;
 	anyPlayerWaited=false;
 }
@@ -229,6 +235,11 @@ void Game::executeOrder(boost::shared_ptr<Order> order, int localPlayer)
 				Building *b=addBuilding(posX, posY, oc->typeNum, oc->teamNumber, oc->unitWorking, oc->unitWorkingFuture);
 				if (b)
 				{
+					if(isVirtual && oc->flagRadius>=0)
+					{
+						b->unitStayRange = oc->flagRadius;
+						b->unitStayRangeLocal = oc->flagRadius;
+					}
 					fprintf(logFile, "ORDER_CREATE (%d, %d, %d)", posX, posY, bt->shortTypeNum);
 					b->owner->addToStaticAbilitiesLists(b);
 					b->update();
@@ -641,6 +652,21 @@ void Game::executeOrder(boost::shared_ptr<Order> order, int localPlayer)
 			}
 		}
 		break;
+		case ORDER_CHANGE_PRIORITY:
+		{
+			Uint16 gid=boost::static_pointer_cast<OrderChangePriority>(order)->gid;
+			Sint32 priority=boost::static_pointer_cast<OrderChangePriority>(order)->priority;
+			int team=Building::GIDtoTeam(gid);
+			int id=Building::GIDtoID(gid);
+			Building *b=teams[team]->myBuildings[id];
+			if (b)
+			{
+				fprintf(logFile, "ORDER_CHANGE_PRIORITY");
+				b->priority = priority;
+				b->updateCallLists();
+			}
+		}
+		break;
 		case ORDER_CANCEL_DELETE:
 		{
 			Uint16 gid=boost::static_pointer_cast<OrderCancelDelete>(order)->gid;
@@ -698,7 +724,6 @@ void Game::executeOrder(boost::shared_ptr<Order> order, int localPlayer)
 			teams[team]->sharedVisionExchange=sao->visionExchangeMask;
 			teams[team]->sharedVisionFood=sao->visionFoodMask;
 			teams[team]->sharedVisionOther=sao->visionOtherMask;
-			setAIAlliance();
 			fprintf(logFile, "ORDER_SET_ALLIANCE");
 		}
 		break;
@@ -730,68 +755,26 @@ void Game::executeOrder(boost::shared_ptr<Order> order, int localPlayer)
 	}
 }
 
-bool Game::isHumanAllAllied(void)
-{
-	Uint32 nonAIMask=0;
-	
-	// AIMask now have the mask of everything which isn't AI
-	for (int i=0; i<mapHeader.getNumberOfTeams(); i++)
-	{
-		nonAIMask |= ((teams[i]->type != BaseTeam::T_AI) ? 1 : 0) << i;
-		//printf("team %d is AI is %d\n", i, teams[i]->type == BaseTeam::T_AI);
-	}
 
-	// if there is any non-AI player with which we aren't allied, return false
-	// or if there is any player allied to AI
-	for (int i=0; i<mapHeader.getNumberOfTeams(); i++)
-		if (teams[i]->type != BaseTeam::T_AI)
+
+void Game::setAlliances(void)
+{
+	for(int i=0; i<mapHeader.getNumberOfTeams(); ++i)
+	{
+		int allyTeam = gameHeader.getAllyTeamNumber(i);
+		teams[i]->allies = 0;
+		teams[i]->enemies = 0;
+		for(int j=0; j<mapHeader.getNumberOfTeams(); ++j)
 		{
-			if (teams[i]->allies != nonAIMask)
-				return false;
-		}
-	
-	return true;
-}
-
-void Game::setAIAlliance(void)
-{
-	if (isHumanAllAllied())
-	{
-		if (verbose)
-			printf("Game : AIs are now allied vs human\n");
-		
-		// all human are allied, ally AI
-		Uint32 aiMask = 0;
-		
-		// find all AI
-		for (int i=0; i<mapHeader.getNumberOfTeams(); i++)
-			if (teams[i]->type == BaseTeam::T_AI)
-				aiMask |= (1<<i);
-		
-		if (verbose)
-			printf("AI mask : %x\n", aiMask);
-				
-		// ally them together
-		
-		for (int i=0; i<mapHeader.getNumberOfTeams(); i++)
-			if (teams[i]->type == BaseTeam::T_AI)
+			int otherAllyTeam = gameHeader.getAllyTeamNumber(j);
+			if(allyTeam == otherAllyTeam)
 			{
-				teams[i]->allies = aiMask;
-				teams[i]->enemies = ~teams[i]->allies;
+				teams[i]->allies |= teams[j]->me;
+				teams[i]->sharedVisionOther |= teams[j]->me;
 			}
-	}
-	else
-	{
-		if (verbose)
-			printf("Game : AIs are now in ffa mode\n");
-		
-		// free for all on AI side
-		for (int i=0; i<mapHeader.getNumberOfTeams(); i++)
-		{
-			if (teams[i]->type == BaseTeam::T_AI)
+			else
 			{
-				teams[i]->allies = teams[i]->me;
-				teams[i]->enemies = ~teams[i]->allies;
+				teams[i]->enemies |= teams[j]->me;
 			}
 		}
 	}
@@ -799,21 +782,6 @@ void Game::setAIAlliance(void)
 
 
 
-void Game::setAIFFA(void)
-{
-	// free for all on AI side
-	for (int i=0; i<mapHeader.getNumberOfTeams(); i++)
-	{
-		if (teams[i]->type == BaseTeam::T_AI)
-		{
-			teams[i]->allies = teams[i]->me;
-			teams[i]->enemies = ~teams[i]->allies;
-		}
-	}
-}
-
-
-
 bool Game::load(GAGCore::InputStream *stream)
 {
 	assert(stream);
@@ -959,11 +927,23 @@ bool Game::load(GAGCore::InputStream *stream)
 	}
 	
 	///Load the campaign text for the game.
-	campaignText = stream->readText("campaignText");
+	if(versionMinor < 75)
+		stream->readText("campaignText");
 	
 	// default prestige calculation
 	prestigeToReach = std::max(MIN_MAX_PRESIGE, mapHeader.getNumberOfTeams()*TEAM_MAX_PRESTIGE);
 
+	if(mapHeader.getVersionMinor() >= 75)
+	{
+		objectives.decodeData(stream, mapHeader.getVersionMinor());
+	}
+	
+	if(mapHeader.getVersionMinor() >= 76)
+	{
+		missionBriefing = stream->readText("briefing");
+		gameHints.decodeData(stream, mapHeader.getVersionMinor());
+	}
+	
 	stream->readLeaveSection();
 	
 	///versions less than 63 did not have fertility computed with the map, but computed it live.
@@ -1086,9 +1066,11 @@ void Game::save(GAGCore::OutputStream *stream, bool fileIsAMap, const std::strin
 
 	///Save the map script state
 	script.save(stream, this);
-	
-	///Save the campaign text
-	stream->writeText(campaignText, "campaignText");
+
+	///Save game objectives
+	objectives.encodeData(stream);
+	stream->writeText(missionBriefing, "missionBriefing");
+	gameHints.encodeData(stream);
 
 	Uint8 sha1[20];
 	for(int i=0; i<20; ++i)
@@ -1175,63 +1157,47 @@ void Game::buildProjectSyncStep(Sint32 localTeam)
 
 void Game::wonSyncStep(void)
 {
-	// prestige of 0 results in infinite prestige
-	if (prestigeToReach > 0)
+	std::list<boost::shared_ptr<WinningCondition> >& conditions = gameHeader.getWinningConditions();
+	bool areAllDecided=true;
+	//We do this twice, because some win conditions depend on other win conditions
+	for(int i=0; i<mapHeader.getNumberOfTeams(); ++i)
 	{
-		totalPrestige=0;
-		isGameEnded=false;
-		int greatestPrestige=0;
-		
-		for (int i=0; i<mapHeader.getNumberOfTeams(); i++)
-		{
-			bool isOtherAlive=false;
-			for (int j=0; j<mapHeader.getNumberOfTeams(); j++)
-			{
-				if(j!=i)
-				{
-					Uint32 playerToMeAllyMask = teams[i]->me & teams[j]->allies;
-					Uint32 meToPlayerAllyMask = teams[j]->me & teams[i]->allies;
-					if((playerToMeAllyMask==0 || meToPlayerAllyMask==0) && teams[j]->isAlive)
-					{
-						isOtherAlive=true;
-					}
-				}
-			}
-			teams[i]->hasWon |= !isOtherAlive;
-			isGameEnded |= teams[i]->hasWon;
-			totalPrestige += teams[i]->prestige;
-			if (greatestPrestige < teams[i]->prestige) greatestPrestige = teams[i]->prestige;
-		}
-	
-		if (totalPrestige >= prestigeToReach)
-		{
-			totalPrestigeReached=true;
-			isGameEnded=true;
-	
-			for (int i=0; i<mapHeader.getNumberOfTeams(); i++)
-				teams[i]->hasWon = teams[i]->prestige == greatestPrestige;
-		}
+		teams[i]->checkWinConditions();
 	}
+	for(int i=0; i<mapHeader.getNumberOfTeams(); ++i)
+	{
+		teams[i]->checkWinConditions();
+		if(teams[i]->winCondition == WCUnknown)
+			areAllDecided=false;
+	}
+	isGameEnded = areAllDecided;
+	
 }
 
 void Game::scriptSyncStep()
 {
 	// do a script step
 	script.syncStep(gui);
+}
 
-	// alter win/loose conditions
+
+
+void Game::prestigeSyncStep()
+{
+	totalPrestige=0;
+	totalPrestigeReached=false;
 	for (int i=0; i<mapHeader.getNumberOfTeams(); i++)
 	{
-		if (teams[i]->isAlive)
-		{
-			if (script.hasTeamWon(i))
-				teams[i]->hasWon=true;
-			if (script.hasTeamLost(i))
-				teams[i]->isAlive=false;
-		}
+		totalPrestige += teams[i]->prestige;
+	}
+	if(totalPrestige >= prestigeToReach)
+	{
+		totalPrestigeReached=true;
 	}
 }
 
+
+
 void Game::syncStep(Sint32 localTeam)
 {
 	if (!anyPlayerWaited)
@@ -1266,9 +1232,10 @@ void Game::syncStep(Sint32 localTeam)
 
 		if ((stepCounter&15)==1)
 			buildProjectSyncStep(localTeam);
-		
+
 		if ((stepCounter&31)==0)
 		{
+			prestigeSyncStep();
 			scriptSyncStep();
 			wonSyncStep();
 		}
@@ -1434,7 +1401,10 @@ Building *Game::addBuilding(int x, int y, int typeNum, int teamNumber, Sint32 un
 			break;
 		}
 	if (id==-1)
+	{
+		//TODO:Building limit reached!
 		return NULL;
+	}
 
 	//ok, now we can safely deposite an building.
 	int gid=Building::GIDfrom(id, teamNumber);
@@ -1609,7 +1579,7 @@ Unit* Game::getUnit(int guid)
 
 
 
-void Game::drawPointBar(int x, int y, BarOrientation orientation, int maxLength, int actLength, Uint8 r, Uint8 g, Uint8 b, int barWidth)
+void Game::drawPointBar(int x, int y, BarOrientation orientation, int maxLength, int actLength, int secondActLength, Uint8 r, Uint8 g, Uint8 b, Uint8 r2, Uint8 g2, Uint8 b2, int barWidth)
 {
 	assert(maxLength>=0);
 	assert(maxLength<65536);
@@ -1629,14 +1599,18 @@ void Game::drawPointBar(int x, int y, BarOrientation orientation, int maxLength,
 			int i;
 			for (i=0; i<actLength; i++)
 				globalContainer->gfx->drawFilledRect(x+i*3+1, y+1, 2, barWidth, r, g, b);
+			for (; i<secondActLength+actLength; i++)
+				globalContainer->gfx->drawFilledRect(x+i*3+1, y+1, 2, barWidth, r2, g2, b2);
 			for (; i<maxLength; i++)
 				globalContainer->gfx->drawRect(x+i*3, y, 4, barWidth+2, r/3, g/3, b/3);
 		}
 		else
 		{
 			int i;
-			for (i=0; i<maxLength-actLength; i++)
+			for (i=0; i<maxLength-secondActLength-actLength; i++)
 				globalContainer->gfx->drawRect(x+i*3, y, 4, barWidth+2, r/3, g/3, b/3);
+			for (; i<maxLength-actLength; i++)
+				globalContainer->gfx->drawFilledRect(x+i*3+1, y+1, 2, barWidth, r2, g2, b2);
 			for (; i<maxLength; i++)
 				globalContainer->gfx->drawFilledRect(x+i*3+1, y+1, 2, barWidth, r, g, b);
 		}
@@ -1655,14 +1629,18 @@ void Game::drawPointBar(int x, int y, BarOrientation orientation, int maxLength,
 			int i;
 			for (i=0; i<actLength; i++)
 				globalContainer->gfx->drawFilledRect(x+1, y+i*3+1, barWidth, 2, r, g, b);
+			for (; i<secondActLength+actLength; i++)
+				globalContainer->gfx->drawFilledRect(x+1, y+i*3+1, barWidth, 2, r2, g2, b2);
 			for (; i<maxLength; i++)
 				globalContainer->gfx->drawRect(x, y+i*3, 4, barWidth+2, r/3, g/3, b/3);
 		}
 		else
 		{
 			int i;
-			for (i=0; i<maxLength-actLength; i++)
+			for (i=0; i<maxLength-secondActLength-actLength; i++)
 				globalContainer->gfx->drawRect(x, y+i*3, 4, barWidth+2, r/3, g/3, b/3);
+			for (; i<maxLength-actLength; i++)
+				globalContainer->gfx->drawFilledRect(x+1, y+i*3+1, barWidth, 2, r2, g2, b2);
 			for (; i<maxLength; i++)
 				globalContainer->gfx->drawFilledRect(x+1, y+i*3+1, barWidth, 2, r, g, b);
 		}
@@ -1805,6 +1783,10 @@ void Game::drawUnit(int x, int y, Uint16 gid, int viewportX, int viewportY, int
 		globalContainer->gfx->drawRect(accessX-4, accessY, accessW+8, accessH, Color(255, 255, 255, 127));
 		globalContainer->gfx->drawString(accessX, accessY, globalContainer->littleFont, oss.str());
 	}
+	if(hilightUnitType & (1<<unit->typeNum))
+	{
+		globalContainer->gfx->drawSprite(px, py-decY-32, globalContainer->gamegui, 36);
+	}
 }
 
 struct BuildingPosComp
@@ -1944,18 +1926,20 @@ inline void Game::drawMapDebugAreas(int left, int top, int right, int bot, int s
 	if (false)
 	{
 		assert(teams[0]);
-		Building *b=teams[0]->myBuildings[0];
+		Building *b=selectedBuilding;
 		if (b)
 			for (int y=top-1; y<=bot; y++)
 				for (int x=left-1; x<=right; x++)
 				{
-					if (map.warpDistMax(b->posX, b->posY, x+viewportX, y+viewportY)<16)
+					//if (map.warpDistMax(b->posX, b->posY, x+viewportX, y+viewportY)<16)
 					{
 						//globalContainer->gfx->drawString((x<<5), (y<<5), globalContainer->littleFont, "%d", map.getGradient(0, 6, 1, x+viewportX, y+viewportY));
 						//globalContainer->gfx->drawString((x<<5), (y<<5), globalContainer->littleFont, "%d", map.warpDistMax(b->posX, b->posY, x+viewportX, y+viewportY));
 						int lx=(x+viewportX-b->posX+15+32)&31;
 						int ly=(y+viewportY-b->posY+15+32)&31;
-						globalContainer->gfx->drawString((x<<5), (y<<5), globalContainer->littleFont, b->localGradient[1][lx+ly*32]);
+						//globalContainer->gfx->drawString((x<<5), (y<<5), globalContainer->littleFont, b->localGradient[1][lx+ly*32]);
+						if(b->globalGradient[1])
+							globalContainer->gfx->drawString((x<<5), (y<<5), globalContainer->littleFont, b->globalGradient[1][(x+viewportX) + (y+viewportY)*map.w]);
 						//globalContainer->gfx->drawString((x<<5), (y<<5)+10, globalContainer->littleFont, lx);
 						//globalContainer->gfx->drawString((x<<5)+16, (y<<5)+10, globalContainer->littleFont, ly);
 						//globalContainer->gfx->drawString((x<<5), (y<<5)+16, globalContainer->littleFont, "%d", x+viewportX);
@@ -2027,9 +2011,178 @@ inline void Game::drawMapDebugAreas(int left, int top, int right, int bot, int s
 	}
 }
 
+inline void Game::drawMapBuilding(int x, int y, int gid, int viewportX, int viewportY, int localTeam, Uint32 drawOptions)
+{
+	Building *building = teams[Building::GIDtoTeam(gid)]->myBuildings[Building::GIDtoID(gid)];
+	assert(building);
+	BuildingType *type=building->type;
+	Team *team=building->owner;
+	
+	int imgid;
+	if (type->crossConnectMultiImage)
+	{
+		int add = 0;
+		Uint16 b;
+		// Up
+		b = map.getBuilding(building->posXLocal, building->posYLocal-1);
+		if ((b != NOGBID) &&
+			(Building::GIDtoTeam(b) == team->teamNumber) && (teams[Building::GIDtoTeam(b)]->myBuildings[Building::GIDtoID(b)]->type == type))
+			add |= (1<<3);
+		// Bottom
+		b = map.getBuilding(building->posXLocal, building->posYLocal+building->type->height);
+		if ((b != NOGBID) &&
+			(Building::GIDtoTeam(b) == team->teamNumber) && (teams[Building::GIDtoTeam(b)]->myBuildings[Building::GIDtoID(b)]->type == type))
+			add |= (1<<2);
+		// Left
+		b = map.getBuilding(building->posXLocal-1, building->posYLocal);
+		if ((b != NOGBID) &&
+			(Building::GIDtoTeam(b) == team->teamNumber) && (teams[Building::GIDtoTeam(b)]->myBuildings[Building::GIDtoID(b)]->type == type))
+			add |= (1<<1);
+		// Right
+		b = map.getBuilding(building->posXLocal+building->type->width, building->posYLocal);
+		if ((b != NOGBID) &&
+			(Building::GIDtoTeam(b) == team->teamNumber) && (teams[Building::GIDtoTeam(b)]->myBuildings[Building::GIDtoID(b)]->type == type))
+			add |= (1<<0);
+		imgid = type->gameSpriteImage + add;
+	}
+	else
+	{
+		// FIXME : why building->hp is > type->hpMax ?
+		int hp = std::min(building->hp, type->hpMax);
+		int damageImgShift = type->gameSpriteCount - ((hp * type->gameSpriteCount) / (type->hpMax+1)) - 1;
+		assert(damageImgShift >= 0);
+		imgid = type->gameSpriteImage + damageImgShift;
+	}
+//	int x, y;
+	int dx, dy;
+	
+//	map.mapCaseToDisplayable(building->posXLocal, building->posYLocal, &x, &y, viewportX, viewportY);
+	
+	// select buildings and set the team colors
+	Sprite *buildingSprite = type->gameSpritePtr;
+	dx = (type->width<<5)-buildingSprite->getW(imgid);
+	dy = (type->height<<5)-buildingSprite->getH(imgid);
+	buildingSprite->setBaseColor(team->color);
+	
+	// draw building
+	globalContainer->gfx->drawSprite(x+dx, y+dy, buildingSprite, imgid);
+	
+	if ((drawOptions & DRAW_BUILDING_RECT) != 0)
+	{
+		int batW=(type->width )<<5;
+		int batH=(type->height)<<5;
+		int typeNum=building->typeNum;
+		globalContainer->gfx->drawRect(x, y, batW, batH, 255, 255, 255, 127);
+	
+		BuildingType *lastbt=globalContainer->buildingsTypes.get(typeNum);
+		int lastTypeNum=typeNum;
+		int max=0;
+		while(lastbt->nextLevel>=0)
+		{
+			lastTypeNum=lastbt->nextLevel;
+			lastbt=globalContainer->buildingsTypes.get(lastTypeNum);
+			if (max++>200)
+			{
+				printf("GameGUI: Error: nextLevelTypeNum architecture is broken.\n");
+				assert(false);
+				break;
+			}
+		}
+		int exBatX=x+((lastbt->decLeft-type->decLeft)<<5);
+		int exBatY=y+((lastbt->decTop-type->decTop)<<5);
+		int exBatW=(lastbt->width)<<5;
+		int exBatH=(lastbt->height)<<5;
+	
+		globalContainer->gfx->drawRect(exBatX, exBatY, exBatW, exBatH, 255, 255, 255, 127);
+	}
+	
+	if (((drawOptions & DRAW_HEALTH_FOOD_BAR) != 0) && (building->owner->sharedVisionOther & teams[localTeam]->me))
+	{
+		//int unitDecx=(building->type->width*16)-((3*building->maxUnitInside)>>1);
+		// TODO : find better color for this
+		// health
+		if (type->hpMax)
+		{
+			int maxWidth, actWidth, addDec;
+			float hpRatio=(float)building->hp/(float)type->hpMax;
+			if (type->width==1)
+			{
+				maxWidth=8;
+				actWidth=1+(int)(7.0f*hpRatio);
+				addDec=2;
+			}
+			else
+			{
+				maxWidth=16;
+				actWidth=1+(int)(15.0f*hpRatio);
+				addDec=7;
+			}
+			int decy=(type->height*32);
+			int healDecx=(type->width-(maxWidth>>3))*16+addDec;
+	
+			if (building->hp!=type->hpMax || !building->type->crossConnectMultiImage)
+			{
+				if (hpRatio>0.6)
+					drawPointBar(x+healDecx, y+decy-4, LEFT_TO_RIGHT, maxWidth, actWidth, 78, 187, 78);
+				else if (hpRatio>0.3)
+					drawPointBar(x+healDecx, y+decy-4, LEFT_TO_RIGHT, maxWidth, actWidth, 255, 255, 0);
+				else
+					drawPointBar(x+healDecx, y+decy-4, LEFT_TO_RIGHT, maxWidth, actWidth, 255, 0, 0);
+			}
+		}
+	
+		// units
+		if (building->maxUnitInside>0)
+			drawPointBar(x+type->width*32-4, y+1, BOTTOM_TO_TOP, building->maxUnitInside, (signed)building->unitsInside.size(), 255, 255, 255);
+		if (building->maxUnitWorking>0)
+			drawPointBar(x+type->width*16-((3*building->maxUnitWorking)>>1), y+1,LEFT_TO_RIGHT , building->maxUnitWorking, (signed)building->unitsWorking.size(), 0, 255, 255, 255, 255, 64, 0);
+	
+		// food (for inns)
+		if ((type->canFeedUnit) || (type->unitProductionTime))
+		{
+			// compute bar size, prevent oversize
+			int bDiv=1;
+			assert(type->height!=0);
+			while ( ((type->maxRessource[CORN]*3+1)/bDiv)>((type->height*32)-10))
+				bDiv++;
+			drawPointBar(x+1, y+1, BOTTOM_TO_TOP, type->maxRessource[CORN]/bDiv, building->ressources[CORN]/bDiv, 255, 255, 120, 1+bDiv);
+		}
+		
+		// bullets (for defence towers)
+		if (type->maxBullets)
+		{
+			// compute bar size, prevent oversize
+			int bDiv=1;
+			assert(type->height!=0);
+			while ( ((type->maxBullets*3+1)/bDiv)>((type->height*32)-10))
+				bDiv++;
+			drawPointBar(x+1, y+1, BOTTOM_TO_TOP, type->maxBullets/bDiv, building->bullets/bDiv, 200, 200, 200, 1+bDiv);
+		}
+	}
+	
+	if (drawOptions & DRAW_ACCESSIBILITY)
+	{
+		std::ostringstream oss;
+		oss << building->owner->teamNumber;
+		int accessW = globalContainer->littleFont->getStringWidth(oss.str().c_str());
+		int accessH = globalContainer->littleFont->getStringHeight(oss.str().c_str());
+		int accessX = x+(((type->width<<5)-accessW)>>1);
+		int accessY = y+(((type->height<<5)-accessH)>>1);
+		globalContainer->gfx->drawFilledRect(accessX-4, accessY, accessW+8, accessH, Color(0, 0, 0, 127));
+		globalContainer->gfx->drawRect(accessX-4, accessY, accessW+8, accessH, Color(255, 255, 255, 127));
+		globalContainer->gfx->drawString(accessX, accessY, globalContainer->littleFont, oss.str());
+	}
+	
+	if(hilightBuildingType & (1<<building->shortTypeNum))
+	{
+		globalContainer->gfx->drawSprite(x + buildingSprite->getW(imgid)/2 - 16, y-36, globalContainer->gamegui, 36);
+	}
+}
+
+
 inline void Game::drawMapGroundBuildings(int left, int top, int right, int bot, int sw, int sh, int viewportX, int viewportY, int localTeam, Uint32 drawOptions, std::set<Building*> *visibleBuildings)
 {
-	std::set<Building *, BuildingPosComp> buildingList;
+	std::set<Building*> drawnBuildings;
 	for (int y=top-1; y<=bot; y++)
 		for (int x=left-1; x<=right; x++)
 		{
@@ -2043,180 +2196,24 @@ inline void Game::drawMapGroundBuildings(int left, int top, int right, int bot,
 				int team = Building::GIDtoTeam(gid);
 
 				Building *building=teams[team]->myBuildings[id];
-				assert(building); // if this fails, and unwanted garbage-UID is on the ground.
-				if (((drawOptions & DRAW_WHOLE_MAP) != 0)
-					|| Building::GIDtoTeam(gid)==localTeam
-					|| (building->seenByMask & teams[localTeam]->me)
-					|| map.isFOWDiscovered(x+viewportX, y+viewportY, teams[localTeam]->me))
+				if(drawnBuildings.find(building)==drawnBuildings.end())
 				{
-					buildingList.insert(building);
-					if (visibleBuildings)
-						visibleBuildings->insert(building);
+					assert(building); // if this fails, and unwanted garbage-UID is on the ground.
+					if (((drawOptions & DRAW_WHOLE_MAP) != 0)
+						|| Building::GIDtoTeam(gid)==localTeam
+						|| (building->seenByMask & teams[localTeam]->me)
+						|| map.isFOWDiscovered(x+viewportX, y+viewportY, teams[localTeam]->me))
+					{
+						int px,py;					
+						map.mapCaseToDisplayable(building->posXLocal, building->posYLocal, &px, &py, viewportX, viewportY);
+					 	drawMapBuilding(px, py, gid, viewportX, viewportY, localTeam, drawOptions);
+						drawnBuildings.insert(building);
+					}
 				}
 			}
 		}
-	
-	for (std::set <Building *, BuildingPosComp>::iterator it=buildingList.begin(); it!=buildingList.end(); ++it)
-	{
-		Building *building = *it;
-		assert(building);
-		BuildingType *type=building->type;
-		Team *team=building->owner;
-
-		int imgid;
-		if (type->crossConnectMultiImage)
-		{
-			int add = 0;
-			Uint16 b;
-			// Up
-			b = map.getBuilding(building->posXLocal, building->posYLocal-1);
-			if ((b != NOGBID) &&
-				(Building::GIDtoTeam(b) == team->teamNumber) && (teams[Building::GIDtoTeam(b)]->myBuildings[Building::GIDtoID(b)]->type == type))
-				add |= (1<<3);
-			// Bottom
-			b = map.getBuilding(building->posXLocal, building->posYLocal+building->type->height);
-			if ((b != NOGBID) &&
-				(Building::GIDtoTeam(b) == team->teamNumber) && (teams[Building::GIDtoTeam(b)]->myBuildings[Building::GIDtoID(b)]->type == type))
-				add |= (1<<2);
-			// Left
-			b = map.getBuilding(building->posXLocal-1, building->posYLocal);
-			if ((b != NOGBID) &&
-				(Building::GIDtoTeam(b) == team->teamNumber) && (teams[Building::GIDtoTeam(b)]->myBuildings[Building::GIDtoID(b)]->type == type))
-				add |= (1<<1);
-			// Right
-			b = map.getBuilding(building->posXLocal+building->type->width, building->posYLocal);
-			if ((b != NOGBID) &&
-				(Building::GIDtoTeam(b) == team->teamNumber) && (teams[Building::GIDtoTeam(b)]->myBuildings[Building::GIDtoID(b)]->type == type))
-				add |= (1<<0);
-			imgid = type->gameSpriteImage + add;
-		}
-		else
-		{
-			// FIXME : why building->hp is > type->hpMax ?
-			int hp = std::min(building->hp, type->hpMax);
-			int damageImgShift = type->gameSpriteCount - ((hp * type->gameSpriteCount) / (type->hpMax+1)) - 1;
-			assert(damageImgShift >= 0);
-			imgid = type->gameSpriteImage + damageImgShift;
-		}
-		int x, y;
-		int dx, dy;
-		map.mapCaseToDisplayable(building->posXLocal, building->posYLocal, &x, &y, viewportX, viewportY);
-
-		// select buildings and set the team colors
-		Sprite *buildingSprite = type->gameSpritePtr;
-		dx = (type->width<<5)-buildingSprite->getW(imgid);
-		dy = (type->height<<5)-buildingSprite->getH(imgid);
-		buildingSprite->setBaseColor(team->color);
-
-		// draw building
-		globalContainer->gfx->drawSprite(x+dx, y+dy, buildingSprite, imgid);
-
-		if ((drawOptions & DRAW_BUILDING_RECT) != 0)
-		{
-			int batW=(type->width )<<5;
-			int batH=(type->height)<<5;
-			int typeNum=building->typeNum;
-			globalContainer->gfx->drawRect(x, y, batW, batH, 255, 255, 255, 127);
-
-			BuildingType *lastbt=globalContainer->buildingsTypes.get(typeNum);
-			int lastTypeNum=typeNum;
-			int max=0;
-			while(lastbt->nextLevel>=0)
-			{
-				lastTypeNum=lastbt->nextLevel;
-				lastbt=globalContainer->buildingsTypes.get(lastTypeNum);
-				if (max++>200)
-				{
-					printf("GameGUI: Error: nextLevelTypeNum architecture is broken.\n");
-					assert(false);
-					break;
-				}
-			}
-			int exBatX=x+((lastbt->decLeft-type->decLeft)<<5);
-			int exBatY=y+((lastbt->decTop-type->decTop)<<5);
-			int exBatW=(lastbt->width)<<5;
-			int exBatH=(lastbt->height)<<5;
-
-			globalContainer->gfx->drawRect(exBatX, exBatY, exBatW, exBatH, 255, 255, 255, 127);
-		}
-
-		if (((drawOptions & DRAW_HEALTH_FOOD_BAR) != 0) && (building->owner->sharedVisionOther & teams[localTeam]->me))
-		{
-			//int unitDecx=(building->type->width*16)-((3*building->maxUnitInside)>>1);
-			// TODO : find better color for this
-			// health
-			if (type->hpMax)
-			{
-				int maxWidth, actWidth, addDec;
-				float hpRatio=(float)building->hp/(float)type->hpMax;
-				if (type->width==1)
-				{
-					maxWidth=8;
-					actWidth=1+(int)(7.0f*hpRatio);
-					addDec=2;
-				}
-				else
-				{
-					maxWidth=16;
-					actWidth=1+(int)(15.0f*hpRatio);
-					addDec=7;
-				}
-				int decy=(type->height*32);
-				int healDecx=(type->width-(maxWidth>>3))*16+addDec;
-
-				if (building->hp!=type->hpMax || !building->type->crossConnectMultiImage)
-				{
-					if (hpRatio>0.6)
-						drawPointBar(x+healDecx, y+decy-4, LEFT_TO_RIGHT, maxWidth, actWidth, 78, 187, 78);
-					else if (hpRatio>0.3)
-						drawPointBar(x+healDecx, y+decy-4, LEFT_TO_RIGHT, maxWidth, actWidth, 255, 255, 0);
-					else
-						drawPointBar(x+healDecx, y+decy-4, LEFT_TO_RIGHT, maxWidth, actWidth, 255, 0, 0);
-				}
-			}
-
-			// units
-			if (building->maxUnitInside>0)
-				drawPointBar(x+type->width*32-4, y+1, BOTTOM_TO_TOP, building->maxUnitInside, (signed)building->unitsInside.size(), 255, 255, 255);
-			if (building->maxUnitWorking>0)
-				drawPointBar(x+type->width*16-((3*building->maxUnitWorking)>>1), y+1,LEFT_TO_RIGHT , building->maxUnitWorking, (signed)building->unitsWorking.size(), 255, 255, 255);
-
-			// food (for inns)
-			if ((type->canFeedUnit) || (type->unitProductionTime))
-			{
-				// compute bar size, prevent oversize
-				int bDiv=1;
-				assert(type->height!=0);
-				while ( ((type->maxRessource[CORN]*3+1)/bDiv)>((type->height*32)-10))
-					bDiv++;
-				drawPointBar(x+1, y+1, BOTTOM_TO_TOP, type->maxRessource[CORN]/bDiv, building->ressources[CORN]/bDiv, 255, 255, 120, 1+bDiv);
-			}
-			
-			// bullets (for defence towers)
-			if (type->maxBullets)
-			{
-				// compute bar size, prevent oversize
-				int bDiv=1;
-				assert(type->height!=0);
-				while ( ((type->maxBullets*3+1)/bDiv)>((type->height*32)-10))
-					bDiv++;
-				drawPointBar(x+1, y+1, BOTTOM_TO_TOP, type->maxBullets/bDiv, building->bullets/bDiv, 200, 200, 200, 1+bDiv);
-			}
-		}
-		
-		if (drawOptions & DRAW_ACCESSIBILITY)
-		{
-			std::ostringstream oss;
-			oss << building->owner->teamNumber;
-			int accessW = globalContainer->littleFont->getStringWidth(oss.str().c_str());
-			int accessH = globalContainer->littleFont->getStringHeight(oss.str().c_str());
-			int accessX = x+(((type->width<<5)-accessW)>>1);
-			int accessY = y+(((type->height<<5)-accessH)>>1);
-			globalContainer->gfx->drawFilledRect(accessX-4, accessY, accessW+8, accessH, Color(0, 0, 0, 127));
-			globalContainer->gfx->drawRect(accessX-4, accessY, accessW+8, accessH, Color(255, 255, 255, 127));
-			globalContainer->gfx->drawString(accessX, accessY, globalContainer->littleFont, oss.str());
-		}
-	}
+	if(visibleBuildings)
+		*visibleBuildings = drawnBuildings;
 }
 
 inline void Game::drawMapAreas(int left, int top, int right, int bot, int sw, int sh, int viewportX, int viewportY, int localTeam, Uint32 drawOptions)
@@ -2833,45 +2830,14 @@ Team *Game::getTeamWithMostPrestige(void)
 	return maxPrestigeTeam;
 }
 
-std::string glob2FilenameToName(const std::string& filename)
+bool Game::isPrestigeWinCondition(void)
 {
-	std::string mapName;
-	if(filename.find(".game")!=std::string::npos)
-		mapName=filename.substr(filename.find("/")+1, filename.size()-6-filename.find("/"));
-	else
-		mapName=filename.substr(filename.find("/")+1, filename.size()-5-filename.find("/"));
-	size_t pos = mapName.find("_");
-	while(pos != std::string::npos)
+	std::list<boost::shared_ptr<WinningCondition> >& conditions = gameHeader.getWinningConditions();
+	for(std::list<boost::shared_ptr<WinningCondition> >::iterator i = conditions.begin(); i!=conditions.end(); ++i)
 	{
-		mapName.replace(pos, 1, " ");
-		pos = mapName.find("_");
+		if((*i)->getType() == WCPrestige)
+			return true;	
 	}
-	return mapName;
+	return false;
 }
 
-template<typename It, typename T>
-class contains: std::unary_function<T, bool>
-{
-public:
-	contains(const It from, const It to) : from(from), to(to) {}
-	bool operator()(T d) { return (std::find(from, to, d) != to); }
-private:
-	const It from;
-	const It to;
-};
-
-std::string glob2NameToFilename(const std::string& dir, const std::string& name, const std::string& extension)
-{
-	const char* pattern = " \t";
-	const char* endPattern = strchr(pattern, '\0');
-	std::string fileName = name;
-	std::replace_if(fileName.begin(), fileName.end(), contains<const char*, char>(pattern, endPattern), '_');
-	std::string fullFileName = dir;
-	fullFileName += DIR_SEPARATOR + fileName;
-	if (extension != "" && extension != "\0")
-	{
-		fullFileName += '.';
-		fullFileName += extension;
-	}
-	return fullFileName;
-}
