@@ -93,7 +93,7 @@ public:
 
 	/// If setGameHeader is true, then the given gameHeader will replace the one loaded with
 	/// the map, otherwise it will be ignored
-	bool loadFromHeaders(MapHeader& mapHeader, GameHeader& gameHeader, bool setGameHeader, bool ignoreGUIData=false);
+	bool loadFromHeaders(MapHeader& mapHeader, GameHeader& gameHeader, bool setGameHeader, bool ignoreGUIData=false, bool saveAI=false);
 	//!
 	bool load(GAGCore::InputStream *stream, bool ignoreGUIData=false);
 	void save(GAGCore::OutputStream *stream, const char *name);
@@ -126,6 +126,67 @@ public:
 	void setCampaignGame(Campaign& campaign, const std::string& missionName);
 	
 	
+	///This is an enum for the current hilight object. The hilighted object is shown with a large arrow.
+	///This is primarily for tutorials
+	enum HilightObject
+	{
+		///This causes the main menu icon to be hilighted
+		HilightMainMenuIcon=1,
+		///This causes all workers on the map to be hilighted
+		HilightWorkers=2,
+		///This causes all explorers on the map to be hilighted
+		HilightExplorers=3,
+		///This causes all warriors on the map to be hilighted
+		HilightWarriors=4,
+		///This causes the right-side menu to be hilighted
+		HilightRightSidePanel=5,
+		///This causes the minimap icons to be hilighted
+		HilightUnderMinimapIcon=6,
+		///This causes the units working bar to be hilighted
+		HilightUnitsAssignedBar=7,
+		///This causes the worker/explorer/warrior ratio bars on a swarm to be hilighted
+		HilightRatioBar=8,
+		///This causes the workers working/free statistic to be hilighted
+		HilightWorkersWorkingFreeStat=9,
+		///This causes the exploresrs working/free statistic to be hilighted
+		HilightExplorersWorkingFreeStat=10,
+		///This causes the warriors working/free statistic to be hilighted
+		HilightWarriorsWorkingFreeStat=11,
+		///This causes the forbidden zone to be hilighted
+		HilightForbiddenZoneOnPanel=12,
+		///This causes the defense zone to be hilighted
+		HilightGuardZoneOnPanel=13,
+		///This causes the clearing zone to be hilighted
+		HilightClearingZoneOnPanel=14,
+		///This causes the brush selector to be hilighted
+		HilightBrushSelector=15,
+		
+		///Anything above this number causes a particular building on the right side menu to be hilighted,
+		///the value is HilightBuilding+IntBuildingType
+		HilightBuildingOnPanel=50,
+		///Anything above this number causes the particular building on the actual map to be hilighted
+		///the value is HilightBuilding+IntBuildingType
+		HilightBuildingOnMap=100,
+	};
+	
+	///Stores the currently hilighted elements
+	std::set<int> hilights;
+	
+	struct HilightArrowPosition
+	{
+		HilightArrowPosition(int x, int y, int sprite) : x(x), y(y), sprite(sprite) {}
+		int x;
+		int y;
+		int sprite;
+	};
+	///The arrows must be the last things to be drawn,
+	///So there positions are stored during the drawing
+	///proccess, and they are drawn last
+	std::vector<HilightArrowPosition> arrowPositions;
+	
+	///This sends the hilight values to the Game class, setting Game::hilightBuildingType and Game::hilightUnitType
+	void updateHilightInGame();
+	
 	KeyboardManager keyboardManager;
 public:
 	Game game;
@@ -165,13 +226,14 @@ private:
 	// Drawing support functions
 	void drawScrollBox(int x, int y, int value, int valueLocal, int act, int max);
 	void drawXPProgressBar(int x, int y, int act, int max);
-	void drawButton(int x, int y, const char *caption, bool doLanguageLookup=true);
+	void drawButton(int x, int y, const char *caption, int r=128, int g=128, int b=128, bool doLanguageLookup=true);
 	void drawBlueButton(int x, int y, const char *caption, bool doLanguageLookup=true);
 	void drawRedButton(int x, int y, const char *caption, bool doLanguageLookup=true);
 	void drawTextCenter(int x, int y, const char *caption);
 	void drawValueAlignedRight(int y, int v);
 	void drawCosts(int ressources[BASIC_COUNT], Font *font);
 	void drawCheckButton(int x, int y, const char* caption, bool isSet);
+	void drawRadioButton(int x, int y, bool isSet);
 
 	void iterateSelection(void);
 	void centerViewportOnSelection(void);
@@ -216,7 +278,7 @@ private:
 	//! Display mode
 	enum DisplayMode
 	{
-		BUILDING_VIEW=0,
+		CONSTRUCTION_VIEW=0,
 		FLAG_VIEW,
 		STAT_TEXT_VIEW,
 		STAT_GRAPH_VIEW,
@@ -251,6 +313,9 @@ private:
 	void clearSelection(void) { setSelection(NO_SELECTION); }
 	void checkSelection(void);
 	
+	/// This function causes all information about the selected unit to be dumped
+	void dumpUnitInformation(void);
+	
 
 	// What's visible or hidden on GUI
 	std::vector<std::string> buildingsChoiceName;
@@ -320,6 +385,7 @@ private:
 		IGM_SAVE,
 		IGM_OPTION,
 		IGM_ALLIANCE,
+		IGM_OBJECTIVES,
 		IGM_END_OF_GAME
 	} inGameMenu;
 	OverlayScreen *gameMenuScreen;
@@ -334,7 +400,7 @@ private:
 	InGameScrollableHistory* scrollableText;
 
 	/// Add a message to the list of messages
-	void addMessage(const GAGCore::Color& color, const std::string &msgText);
+	void addMessage(const GAGCore::Color& color, const std::string &msgText, bool chat);
 
 	// Message stuff
 	int eventGoPosX, eventGoPosY; //!< position on map of last event
