@@ -17,30 +17,33 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
 
+#include "boost/lexical_cast.hpp"
 #include "GameGUIDialog.h"
 #include "GameGUI.h"
 #include "GlobalContainer.h"
-#include "SoundMixer.h"
-#include <GUIButton.h>
-#include <GUIText.h>
-#include <GUIAnimation.h>
-#include <GUISelector.h>
-#include <Toolkit.h>
-#include <StringTable.h>
+#include "GUIAnimation.h"
+#include "GUIButton.h"
+#include "GUISelector.h"
+#include "GUITextArea.h"
+#include "GUIText.h"
 #include "Player.h"
+#include "SoundMixer.h"
+#include "StringTable.h"
+#include "Toolkit.h"
 
 
 //! Main menu screen
 InGameMainScreen::InGameMainScreen(bool showAlliance)
-:OverlayScreen(globalContainer->gfx, 320, 310)
+:OverlayScreen(globalContainer->gfx, 320, 360)
 {
 	addWidget(new TextButton(0, 10, 300, 40, ALIGN_CENTERED, ALIGN_LEFT, "menu", Toolkit::getStringTable()->getString("[load game]"), LOAD_GAME));
 	addWidget(new TextButton(0, 60, 300, 40, ALIGN_CENTERED, ALIGN_LEFT, "menu", Toolkit::getStringTable()->getString("[save game]"), SAVE_GAME));
 	addWidget(new TextButton(0, 110, 300, 40, ALIGN_CENTERED, ALIGN_LEFT, "menu", Toolkit::getStringTable()->getString("[options]"), OPTIONS));
 	if (showAlliance)
 		addWidget(new TextButton(0, 160, 300, 40, ALIGN_CENTERED, ALIGN_LEFT, "menu", Toolkit::getStringTable()->getString("[alliances]"), ALLIANCES));
-	addWidget(new TextButton(0, 210, 300, 40, ALIGN_CENTERED, ALIGN_LEFT, "menu", Toolkit::getStringTable()->getString("[quit the game]"), QUIT_GAME));
-	addWidget(new TextButton(0, 260, 300, 40, ALIGN_CENTERED, ALIGN_LEFT, "menu", Toolkit::getStringTable()->getString("[return to game]"), RETURN_GAME, 27));
+	addWidget(new TextButton(0, 210, 300, 40, ALIGN_CENTERED, ALIGN_LEFT, "menu", Toolkit::getStringTable()->getString("[objectives]"), OBJECTIVES));
+	addWidget(new TextButton(0, 260, 300, 40, ALIGN_CENTERED, ALIGN_LEFT, "menu", Toolkit::getStringTable()->getString("[quit the game]"), QUIT_GAME));
+	addWidget(new TextButton(0, 310, 300, 40, ALIGN_CENTERED, ALIGN_LEFT, "menu", Toolkit::getStringTable()->getString("[return to game]"), RETURN_GAME, 27));
 	dispatchInit();
 }
 
@@ -72,6 +75,7 @@ void InGameEndOfGameScreen::onAction(Widget *source, Action action, int par1, in
 InGameAllianceScreen::InGameAllianceScreen(GameGUI *gameGUI)
 :OverlayScreen(globalContainer->gfx, (gameGUI->game.gameHeader.getNumberOfPlayers() - countNumberPlayersForLocalTeam(gameGUI->game.gameHeader, gameGUI->localTeamNo)<=8) ? 320 : 600, 395)
 {
+
 	// fill the slots
 	int i;
 	int xBase=0;
@@ -99,12 +103,19 @@ InGameAllianceScreen::InGameAllianceScreen(GameGUI *gameGUI)
 		texts[i]->setStyle(Font::Style(Font::STYLE_NORMAL, team->color));
 		addWidget(texts[i]);
 		
+	
 		alliance[i]=new OnOffButton(172+xBase, 40+yBase,  20, 20, ALIGN_LEFT, ALIGN_LEFT, (gameGUI->localTeam->allies & otherTeamMask) != 0, ALLIED+i);
 		addWidget(alliance[i]);
-		
+	
 		normalVision[i]=new OnOffButton(196+xBase, 40+yBase,  20, 20, ALIGN_LEFT, ALIGN_LEFT, (gameGUI->localTeam->sharedVisionOther & otherTeamMask) != 0, NORMAL_VISION+i);
 		addWidget(normalVision[i]);
 		
+		if(gameGUI->game.gameHeader.areAllyTeamsFixed())
+		{
+			alliance[i]->visible=false;
+			normalVision[i]->visible=false;
+		}
+		
 		foodVision[i]=new OnOffButton(220+xBase, 40+yBase,  20, 20, ALIGN_LEFT, ALIGN_LEFT, (gameGUI->localTeam->sharedVisionFood & otherTeamMask) != 0, FOOD_VISION+i);
 		addWidget(foodVision[i]);
 		
@@ -117,9 +128,9 @@ InGameAllianceScreen::InGameAllianceScreen(GameGUI *gameGUI)
 		
 		if(otherTeam == gameGUI->localTeamNo)
 		{
-			texts[i]->visible=false;
 			alliance[i]->visible=false;
 			normalVision[i]->visible=false;
+			texts[i]->visible=false;
 			foodVision[i]->visible=false;
 			marketVision[i]->visible=false;
 			chat[i]->visible=false;
@@ -144,6 +155,21 @@ InGameAllianceScreen::InGameAllianceScreen(GameGUI *gameGUI)
 		marketVision[i] = NULL;
 		chat[i] = NULL;
 	}
+	
+	//Put locks if needed
+	if(gameGUI->game.gameHeader.areAllyTeamsFixed())
+	{
+		int np = std::max(2, gameGUI->game.gameHeader.getNumberOfPlayers() - countNumberPlayersForLocalTeam(gameGUI->game.gameHeader, gameGUI->localTeamNo));
+		//Although this is the animation widget, we are just using it to display a still frame
+		addWidget(new Animation(172, 40 + std::min(4, np/2)*25 - 16, ALIGN_LEFT, ALIGN_TOP, "data/gfx/gamegui", 35));
+		addWidget(new Animation(196, 40 + std::min(4, np/2)*25 - 16, ALIGN_LEFT, ALIGN_TOP, "data/gfx/gamegui", 35));
+		
+		if(np>8)
+		{
+			addWidget(new Animation(172, 40 + std::min(4, (np-8)/2)*25 - 16, ALIGN_LEFT, ALIGN_TOP, "data/gfx/gamegui", 35));
+			addWidget(new Animation(196, 40 + std::min(4, (np-8)/2)*25 - 16, ALIGN_LEFT, ALIGN_TOP, "data/gfx/gamegui", 35));
+		}
+	}
 
 	// add static text and images
 	addWidget(new Text(172+3, 13, ALIGN_LEFT, ALIGN_LEFT, "standard", "A")); 
@@ -333,7 +359,6 @@ InGameOptionScreen::InGameOptionScreen(GameGUI *gameGUI)
 	}
 
 	addWidget(new TextButton(0, 250, 300, 40, ALIGN_CENTERED, ALIGN_LEFT, "menu", Toolkit::getStringTable()->getString("[ok]"), OK, 27));
-	dispatchInit();
 	
 	std::ostringstream oss;
 	oss << globalContainer->gfx->getW() << "x" << globalContainer->gfx->getH();
@@ -343,6 +368,7 @@ InGameOptionScreen::InGameOptionScreen(GameGUI *gameGUI)
 		oss << " SDL";
 		
 	addWidget(new Text(0, 200, ALIGN_FILL, ALIGN_TOP, "standard", oss.str().c_str()));
+	dispatchInit();
 }
 
 
@@ -376,3 +402,204 @@ void InGameOptionScreen::onAction(Widget *source, Action action, int par1, int p
 		globalContainer->mix->setVolume(musicVol->getValue(), voiceVol->getValue(), mute->getState());
 	}
 }
+
+
+
+InGameObjectivesScreen::InGameObjectivesScreen(GameGUI* gui, bool showBriefing)
+:OverlayScreen(globalContainer->gfx, 470, 390)
+{
+	addWidget(new TextButton(10, 40, 143, 25, ALIGN_LEFT, ALIGN_TOP, "menu", Toolkit::getStringTable()->getString("[objectives]"), OBJECTIVES));
+
+	int hints_x = 317;
+	if(gui->game.missionBriefing.empty())
+	{
+		hints_x = 163;
+	}
+	else
+	{
+		addWidget(new TextButton(163, 40, 144, 25, ALIGN_LEFT, ALIGN_TOP, "menu", Toolkit::getStringTable()->getString("[briefing]"), BRIEFING));
+	}
+	addWidget(new TextButton(hints_x, 40, 143, 25, ALIGN_LEFT, ALIGN_TOP, "menu", Toolkit::getStringTable()->getString("[hints]"), HINTS));
+	
+	
+	
+	objectives = new Text(0, 10, ALIGN_FILL, ALIGN_TOP, "menu", Toolkit::getStringTable()->getString("[objectives]"));
+	briefing = new Text(0, 10, ALIGN_FILL, ALIGN_TOP, "menu", Toolkit::getStringTable()->getString("[briefing]"));
+	hints = new Text(0, 10, ALIGN_FILL, ALIGN_TOP, "menu", Toolkit::getStringTable()->getString("[hints]"));
+	
+	objectivesWidgets.push_back(objectives);
+	briefingWidgets.push_back(briefing);
+	hintsWidgets.push_back(hints);
+	
+	
+	std::string text;
+	
+	//This group of widgets is all for the objectives tab
+	objectivesWidgets.push_back(new Text(10, 70, ALIGN_LEFT, ALIGN_TOP, "menu", Toolkit::getStringTable()->getString("[Primary Objectives]")));
+	int n=0;
+	for(int i=0; i<gui->game.objectives.getNumberOfObjectives(); ++i)
+	{
+		if(gui->game.objectives.isObjectiveVisible(i) && gui->game.objectives.getObjectiveType(i) == GameObjectives::Primary)
+		{
+			text = gui->game.objectives.getGameObjectiveText(i);
+			if(Toolkit::getStringTable()->doesStringExist(text.c_str()))
+				text = Toolkit::getStringTable()->getString(text.c_str());
+			objectivesWidgets.push_back(new Text(50, 100 + 30*n, ALIGN_LEFT, ALIGN_TOP, "standard", text.c_str()));
+			Uint8 state = 0;
+			if(gui->game.objectives.isObjectiveComplete(i))
+				state = 1;
+			else if(gui->game.objectives.isObjectiveFailed(i))
+				state = 2;
+			TriButton* b = new TriButton(20, 100 + 30*n, 20, 20, ALIGN_LEFT, ALIGN_TOP, state, i);
+			b->setClickable(false);
+			objectivesWidgets.push_back(b);
+			n+=1;
+		}
+	}
+	if(n == 0)
+	{
+		objectivesWidgets.push_back(new Text(50, 100 + 30*n, ALIGN_LEFT, ALIGN_TOP, "standard", Toolkit::getStringTable()->getString("[No Objectives]")));
+		n+=1;
+	}
+	
+	bool isSecondary = false;
+	for(int i=0; i<gui->game.objectives.getNumberOfObjectives(); ++i)
+	{
+		if(gui->game.objectives.getObjectiveType(i) == GameObjectives::Secondary)
+		{
+			isSecondary = true;
+			break;
+		}
+	}
+	
+	if(isSecondary)
+	{
+		objectivesWidgets.push_back(new Text(10, 100 + 30*n, ALIGN_LEFT, ALIGN_TOP, "menu", Toolkit::getStringTable()->getString("[Secondary Objectives]")));
+		for(int i=0; i<gui->game.objectives.getNumberOfObjectives(); ++i)
+		{
+			if(gui->game.objectives.isObjectiveVisible(i) && gui->game.objectives.getObjectiveType(i) == GameObjectives::Secondary)
+			{
+				text = gui->game.objectives.getGameObjectiveText(i);
+				if(Toolkit::getStringTable()->doesStringExist(text.c_str()))
+					text = Toolkit::getStringTable()->getString(text.c_str());
+				objectivesWidgets.push_back(new Text(50, 130 + 30*n, ALIGN_LEFT, ALIGN_TOP, "standard", text.c_str()));
+				Uint8 state = 0;
+				if(gui->game.objectives.isObjectiveComplete(i))
+					state = 1;
+				else if(gui->game.objectives.isObjectiveFailed(i))
+					state = 2;
+				TriButton* b = new TriButton(20, 130 + 30*n, 20, 20, ALIGN_LEFT, ALIGN_TOP, state, i);
+				b->setClickable(false);
+				objectivesWidgets.push_back(b);
+				n+=1;
+			}
+		}
+	}
+	
+	text = gui->game.missionBriefing;
+	if(Toolkit::getStringTable()->doesStringExist(text.c_str()))
+		text = Toolkit::getStringTable()->getString(text.c_str());
+		
+	//This group of widgets is for the mission briefing tab
+	briefingWidgets.push_back(new TextArea(10, 70, 450, 260, ALIGN_LEFT, ALIGN_TOP, "standard", true, text.c_str()));
+	
+	//This group of widgets is for the hints tab
+	n=0;
+	for(int i=0; i<gui->game.gameHints.getNumberOfHints(); ++i)
+	{
+		if(gui->game.gameHints.isHintVisible(i))
+		{
+			text = gui->game.gameHints.getGameHintText(i);
+			if(Toolkit::getStringTable()->doesStringExist(text.c_str()))
+				text = Toolkit::getStringTable()->getString(text.c_str());
+			text = boost::lexical_cast<std::string>(n+1) + ") " + text;
+			hintsWidgets.push_back(new Text(50, 70 + 25*n, ALIGN_LEFT, ALIGN_TOP, "standard", text.c_str()));
+			n+=1;
+		}
+	}
+	if(n == 0)
+	{
+		hintsWidgets.push_back(new Text(50, 70 + 25*n, ALIGN_LEFT, ALIGN_TOP, "standard", Toolkit::getStringTable()->getString("[No Hints]")));
+		n+=1;
+	}
+	
+	//Add the widgets to the menu
+	for(int i=0; i<objectivesWidgets.size(); i++)
+	{
+		objectivesWidgets[i]->visible=!showBriefing;
+		addWidget(objectivesWidgets[i]);
+	}
+	for(int i=0; i<briefingWidgets.size(); i++)
+	{
+		briefingWidgets[i]->visible=showBriefing;
+		addWidget(briefingWidgets[i]);
+	}
+	for(int i=0; i<hintsWidgets.size(); i++)
+	{
+		hintsWidgets[i]->visible=false;
+		addWidget(hintsWidgets[i]);
+	}
+	
+	// add ok button
+	addWidget(new TextButton(0, 340, 300, 40, ALIGN_CENTERED, ALIGN_LEFT, "menu", Toolkit::getStringTable()->getString("[ok]"), OK, 27));
+	dispatchInit();
+}
+
+
+
+void InGameObjectivesScreen::onAction(Widget *source, Action action, int par1, int par2)
+{
+	if ((action==BUTTON_RELEASED) || (action==BUTTON_SHORTCUT))
+	{
+		if(par1 == OK)
+		{
+			endValue=par1;
+		}
+		else if(par1 == OBJECTIVES)
+		{
+			for(int i=0; i<objectivesWidgets.size(); i++)
+			{
+				objectivesWidgets[i]->visible=true;
+			}
+			for(int i=0; i<briefingWidgets.size(); i++)
+			{
+				briefingWidgets[i]->visible=false;
+			}
+			for(int i=0; i<hintsWidgets.size(); i++)
+			{
+				hintsWidgets[i]->visible=false;
+			}
+		}
+		else if(par1 == BRIEFING)
+		{
+			for(int i=0; i<objectivesWidgets.size(); i++)
+			{
+				objectivesWidgets[i]->visible=false;
+			}
+			for(int i=0; i<briefingWidgets.size(); i++)
+			{
+				briefingWidgets[i]->visible=true;
+			}
+			for(int i=0; i<hintsWidgets.size(); i++)
+			{
+				hintsWidgets[i]->visible=false;
+			}
+		}
+		else if(par1 == HINTS)
+		{
+			for(int i=0; i<objectivesWidgets.size(); i++)
+			{
+				objectivesWidgets[i]->visible=false;
+			}
+			for(int i=0; i<briefingWidgets.size(); i++)
+			{
+				briefingWidgets[i]->visible=false;
+			}
+			for(int i=0; i<hintsWidgets.size(); i++)
+			{
+				hintsWidgets[i]->visible=true;
+			}
+		}
+	}
+}
+
