@@ -21,6 +21,7 @@
 #define __GLOB2_SCREEN_H
 
 #include <GUIBase.h>
+#include <GUITabScreen.h>
 
 using namespace GAGCore;
 using namespace GAGGUI;
@@ -37,5 +38,17 @@ private:
 	int randomSeed;
 };
 
+class Glob2TabScreen : public TabScreen
+{
+public:
+	Glob2TabScreen(bool fullScreen, bool longerButtons=false);
+	virtual ~Glob2TabScreen();
+	virtual void paint(void);
+	
+private:
+	unsigned getNextTerrain(void);
+	int randomSeed;
+};
+
 #endif
 
