@@ -4,7 +4,7 @@
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
+  the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.
 
   This program is distributed in the hope that it will be useful,
@@ -185,6 +185,30 @@ void Glob2Style::drawScrollBar(GAGCore::DrawableSurface *target, int x, int y, i
 	target->setClipRect(ocrX, ocrY, ocrW, ocrH);
 }
 
+void Glob2Style::drawProgressBar(GAGCore::DrawableSurface *target, int x, int y, int w, int value, int range)
+{
+	int h = getStyleMetric(STYLE_METRIC_PROGRESS_BAR_HEIGHT);
+	drawFrame(target, x, y, w, h, Color::ALPHA_OPAQUE);
+	x += getStyleMetric(STYLE_METRIC_FRAME_LEFT_WIDTH);
+	y += getStyleMetric(STYLE_METRIC_FRAME_TOP_HEIGHT);
+	w -= getStyleMetric(STYLE_METRIC_FRAME_LEFT_WIDTH) + getStyleMetric(STYLE_METRIC_FRAME_RIGHT_WIDTH);
+	h -= getStyleMetric(STYLE_METRIC_FRAME_TOP_HEIGHT) + getStyleMetric(STYLE_METRIC_FRAME_BOTTOM_HEIGHT);
+	
+	int len = (value*w)/range;
+	
+	target->drawFilledRect(x, y, w, h, Color(168, 150, 90));
+	
+	// save cliprect
+	int ocrX, ocrY, ocrW, ocrH;
+	target->getClipRect(&ocrX, &ocrY, &ocrW, &ocrH);
+	target->setClipRect(x, y, len, h);
+	for (int i = 0; i < len; i += sprite->getW(24))
+		target->drawSprite(x + i, y, sprite, 24);
+	
+	// reset cliprect
+	target->setClipRect(ocrX, ocrY, ocrW, ocrH);
+}
+
 int Glob2Style::getStyleMetric(StyleMetrics metric)
 {
 	switch (metric)
@@ -196,7 +220,8 @@ int Glob2Style::getStyleMetric(StyleMetrics metric)
 		case STYLE_METRIC_LIST_SCROLLBAR_WIDTH: return sprite->getW(20);
 		case STYLE_METRIC_LIST_SCROLLBAR_TOP_WIDTH: return sprite->getH(20);
 		case STYLE_METRIC_LIST_SCROLLBAR_BOTTOM_WIDTH: return sprite->getH(22);
-		default: return 0;
+		case STYLE_METRIC_PROGRESS_BAR_HEIGHT: return sprite->getH(24) + getStyleMetric(STYLE_METRIC_FRAME_TOP_HEIGHT) + getStyleMetric(STYLE_METRIC_FRAME_BOTTOM_HEIGHT);
+		default: return Style::getStyleMetric(metric);
 	}
 }
 
