@@ -32,6 +32,7 @@ namespace GAGCore
 	class FileManager;
 	class GraphicContext;
 	class Sprite;
+	class DrawableSurface;
 	class Font;
 }
 using namespace GAGCore;
@@ -48,9 +49,7 @@ public:
 	enum { OPTION_LOW_SPEED_GFX=0x1 };
 
 private:
-	void initProgressBar(void);
-	void updateLoadProgressBar(int value);
-	void destroyProgressBar(void);
+	void updateLoadProgressScreen(int value);
 
 	std::string userName;
 	
@@ -75,6 +74,8 @@ public:
 	SoundMixer *mix;
 	VoiceRecorder *voiceRecorder;
 	
+	DrawableSurface *title;
+	
 	Sprite *terrain;
 	Sprite *terrainWater;
 	Sprite *terrainCloud;
@@ -114,7 +115,11 @@ public:
 	
 	bool runTestGames; //! runs test games
 	
+	bool runTestMapGeneration; //! runs test map generation
+	
 	bool hostServer;
+	bool hostRouter;
+	bool adminRouter;
 	char hostServerMapName[32];
 	char hostServerUserName[32];
 	char hostServerPassWord[32];
