@@ -4,7 +4,7 @@
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
+  the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.
 
   This program is distributed in the hope that it will be useful,
@@ -40,6 +40,9 @@ LogFileManager::~LogFileManager()
 
 FILE *LogFileManager::getFile(const char *fileName)
 {
+	///This is a hack to temporarilly disable log files
+	return stdout;
+
 	std::string logName = "logs/";
 	logName += globalContainer->getUsername();
 	logName += fileName;
