@@ -4,7 +4,7 @@
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
+  the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.
 
   This program is distributed in the hope that it will be useful,
@@ -43,6 +43,9 @@ to the same file, without opening nor closing any file.
 This way we can have all log data of all instances of the same class in the same file.
 */
 
+///This is a hack to temporarilly disable log files
+#define fprintf if(false)fprintf
+
 class LogFileManager
 {
 public:
