@@ -21,20 +21,21 @@
 #include "NetMessage.h"
 
 
-NetEngine::NetEngine(int numberOfPlayers, int localPlayer, int networkOrderRate, boost::shared_ptr<YOGClient> client)
-	: numberOfPlayers(numberOfPlayers), localPlayer(localPlayer), client(client), networkOrderRate(networkOrderRate)
+NetEngine::NetEngine(int numberOfPlayers, int localPlayer, int networkOrderRate, boost::shared_ptr<NetConnection> router)
+	: numberOfPlayers(numberOfPlayers), localPlayer(localPlayer), router(router), networkOrderRate(networkOrderRate)
 {
 	step=0;
 	orders.resize(numberOfPlayers);
 	localOrderSendCountdown = 0;
+	currentLatency = 0;
 }
 
 
 
-void NetEngine::setNetworkInfo(int nnetworkOrderRate, boost::shared_ptr<YOGClient> nclient)
+void NetEngine::setNetworkInfo(int nnetworkOrderRate, boost::shared_ptr<NetConnection> nrouter)
 {
 	networkOrderRate = nnetworkOrderRate;
-	client = nclient;
+	router = nrouter;
 }
 
 
@@ -57,11 +58,11 @@ void NetEngine::advanceStep(Uint32 checksum)
 		}
 
 		localOrder->gameCheckSum = checksum;
-		if(client)
+		if(router)
 		{
 			localOrder->sender = localPlayer;
 			shared_ptr<NetSendOrder> message(new NetSendOrder(localOrder));
-			client->sendNetMessage(message);
+			router->sendMessage(message);
 		}
 		pushOrder(localOrder, localPlayer, false);
 		localOrderSendCountdown = networkOrderRate - 1;
@@ -78,7 +79,27 @@ void NetEngine::clearTopOrders()
 {
 	for(int p=0; p<numberOfPlayers; ++p)
 	{
-		orders[p].pop();
+		boost::shared_ptr<Order> o = orders[p].front();
+		///Handle latency adjustment order
+		if(o->getOrderType() == ORDER_ADJUST_LATENCY)
+		{
+			boost::shared_ptr<AdjustLatency> al = boost::static_pointer_cast<AdjustLatency>(o);
+			int diff = (al->latencyAdjustment) - currentLatency;
+			if(diff>0)
+			{
+				for(int i=0; i<diff; ++i)
+				{
+					for(int p=0; p<orders.size(); ++p)
+					{
+						boost::shared_ptr<Order> order = boost::shared_ptr<Order>(new NullOrder);
+						order->sender=p;
+						orders[p].insert(orders[p].begin(), order);
+					}
+				}
+			}
+			currentLatency = al->latencyAdjustment;
+		}
+		orders[p].erase(orders[p].begin());
 	}
 }
 
@@ -88,7 +109,7 @@ void NetEngine::pushOrder(boost::shared_ptr<Order> order, int playerNumber, bool
 {
 	assert(playerNumber>=0);
 	order->sender=playerNumber;
-	orders[playerNumber].push(order);
+	orders[playerNumber].push_back(order); 
 
 	///The local player and network players all have padding arround their order
 	if(! isAI)
@@ -97,7 +118,7 @@ void NetEngine::pushOrder(boost::shared_ptr<Order> order, int playerNumber, bool
 		{
 			shared_ptr<Order> norder(new NullOrder);
 			norder->sender=playerNumber;
-			orders[playerNumber].push(norder);
+			orders[playerNumber].push_back(norder);
 		}
 	}
 }
@@ -106,7 +127,7 @@ void NetEngine::pushOrder(boost::shared_ptr<Order> order, int playerNumber, bool
 
 boost::shared_ptr<Order> NetEngine::retrieveOrder(int playerNumber)
 {
-	return orders[playerNumber].front();
+  return *orders[playerNumber].begin();
 }
 
 
@@ -151,11 +172,11 @@ void NetEngine::flushAllOrders()
 		outgoing.pop();
 		localOrder->gameCheckSum = static_cast<unsigned int>(-1);
 
-		if(client)
+		if(router)
 		{
 			localOrder->sender = localPlayer;
 			shared_ptr<NetSendOrder> message(new NetSendOrder(localOrder));
-			client->sendNetMessage(message);
+			router->sendMessage(message);
 		}
 		pushOrder(localOrder, localPlayer, false);
 
@@ -167,6 +188,7 @@ void NetEngine::flushAllOrders()
 
 void NetEngine::prepareForLatency(int playerNumber, int latency)
 {
+	currentLatency = latency;
 	for(int s=0; s<latency; ++s)
 	{
 		pushOrder(boost::shared_ptr<Order>(new NullOrder), playerNumber, true);
@@ -221,3 +243,10 @@ bool NetEngine::matchCheckSums()
 	return true;
 }
 
+
+
+void NetEngine::increaseLatencyAdjustment()
+{
+	boost::shared_ptr<AdjustLatency> latency(new AdjustLatency(currentLatency+1));
+	addLocalOrder(latency);
+}
