@@ -23,7 +23,7 @@
 #include <boost/shared_ptr.hpp>
 #include <vector>
 #include <queue>
-#include "YOGClient.h"
+#include "NetConnection.h"
 
 ///The purpose of this class is to sort Orders, and hand them out in
 ///the correct time slot. It serves partially to hide latency, Orders
@@ -34,10 +34,10 @@ class NetEngine
 {
 public:
 	///Constructs the NetEngine
-	NetEngine(int numberOfPlayers, int localPlayer, int networkOrderRate = 1, boost::shared_ptr<YOGClient> client = boost::shared_ptr<YOGClient>());
+	NetEngine(int numberOfPlayers, int localPlayer, int networkOrderRate = 1, boost::shared_ptr<NetConnection> router = boost::shared_ptr<NetConnection>());
 
 	///Sets the network game info
-	void setNetworkInfo(int networkOrderRate, boost::shared_ptr<YOGClient> client);
+	void setNetworkInfo(int networkOrderRate, boost::shared_ptr<NetConnection> client);
 
 	///Advances the step
 	void advanceStep(Uint32 checksum);
@@ -80,11 +80,14 @@ public:
 	///Checks the checksums of all players for this step.
 	///returns false if they don't match
 	bool matchCheckSums();
+
+	///This sends an order through the network that causes the latency adjustment to be increased
+	void increaseLatencyAdjustment();
 	
 private:
 
 	///This stores the queues with the orders from each player
-	std::vector<std::queue<boost::shared_ptr<Order> > > orders;
+	std::vector<std::vector<boost::shared_ptr<Order> > > orders;
 	///This queue stores all of the local orders that have to be sent out
 	///on their turn
 	std::queue<boost::shared_ptr<Order> > outgoing;
@@ -93,8 +96,9 @@ private:
 	///This count-downs steps until an order is sent across the network
 	int localOrderSendCountdown;
 	int localPlayer;
-	boost::shared_ptr<YOGClient> client;
+	boost::shared_ptr<NetConnection> router;
 	int networkOrderRate;
+	int currentLatency;
 };
 
 
