@@ -20,6 +20,7 @@
 #include "FormatableString.h"
 #include "YOGServerGame.h"
 #include "Player.h"
+#include "AINames.h"
 
 using namespace GAGCore;
 
@@ -76,7 +77,7 @@ void NetGamePlayerManager::addAIPlayer(AI::ImplementitionID type)
 			if(bp.type == BasePlayer::P_NONE)
 			{
 				FormatableString name("%0 %1");
-				name.arg(AI::getAIText(type)).arg(x+1);
+				name.arg(AINames::getAIText(type)).arg(x+1);
 				bp = BasePlayer(x, name, team_number, Player::playerTypeFromImplementitionID(type));
 				readyToStart[x] = true;
 				break;
@@ -117,7 +118,7 @@ void NetGamePlayerManager::removePlayer(int playerNumber)
 			if(bp.type >= Player::P_AI)
 			{
 				FormatableString name("%0 %1");
-				name.arg(AI::getAIText(bp.type - (int)Player::P_AI)).arg(bp.number+1);
+				name.arg(AINames::getAIText(bp.type - (int)Player::P_AI)).arg(bp.number+1);
 				bp.name = name;
 			}
 
@@ -170,6 +171,20 @@ bool NetGamePlayerManager::isEveryoneReadyToGo()
 
 
 
+bool NetGamePlayerManager::isReadyToGo(int playerID)
+{
+	for(int x=0; x<32; ++x)
+	{
+		BasePlayer& bp = gameHeader.getBasePlayer(x);
+		if(bp.playerID == playerID)
+		{
+			return readyToStart[x];
+		}
+	}
+}
+
+
+
 void NetGamePlayerManager::setNumberOfTeams(int nnumberOfTeams)
 {
 	numberOfTeams = nnumberOfTeams;
@@ -184,6 +199,13 @@ void NetGamePlayerManager::setReteamingInformation(const NetReteamingInformation
 
 
 
+const NetReteamingInformation& NetGamePlayerManager::getReteamingInformation() const
+{
+	return reteamInfo;
+}
+
+
+
 int NetGamePlayerManager::chooseTeamNumber()
 {
 	//Find a spare team number to give to the player. If there aren't any, recycle a number that has the fewest number of attached players
