@@ -44,12 +44,16 @@ public:
 	void setReadyToGo(int playerID, bool isReady);
 	///Tells whether all players are ready to go
 	bool isEveryoneReadyToGo();
+	///Returns true if a particular player is ready to go
+	bool isReadyToGo(int playerID);
 	///Sets the number of teams
 	void setNumberOfTeams(int numberOfTeams);
 	///Sets the reteaming information. Reteaming is when you reload a YOG save
 	///game in YOG, and if the same players join, they are automatically set to
 	///the team they where in the save game
 	void setReteamingInformation(const NetReteamingInformation& information);
+	///This returns the reteaming information
+	const NetReteamingInformation& getReteamingInformation() const;
 private:
 	///Chooses a team number that has the fewest attached players
 	int chooseTeamNumber();
