@@ -66,6 +66,8 @@ NewMapScreen::NewMapScreen()
 	methodes->addText(Toolkit::getStringTable()->getString("[river terrain]"));
 	methodes->addText(Toolkit::getStringTable()->getString("[islands terrain]"));
 	methodes->addText(Toolkit::getStringTable()->getString("[crater lakes terrain]"));
+	methodes->addText(Toolkit::getStringTable()->getString("[concrete islands terrain]"));
+	methodes->addText(Toolkit::getStringTable()->getString("[isles terrain]"));
 	methodes->addText(Toolkit::getStringTable()->getString("[old random terrain]"));
 	methodes->addText(Toolkit::getStringTable()->getString("[old islands terrain]"));
 	methodes->setSelectionIndex(0);
@@ -95,10 +97,12 @@ NewMapScreen::NewMapScreen()
 	nbTeams->add(10);
 	nbTeams->add(11);
 	nbTeams->add(12);
+	/*
 	nbTeams->add(13);
 	nbTeams->add(14);
 	nbTeams->add(15);
 	nbTeams->add(16);
+	*/
 	nbTeams->setNth(descriptor.nbTeams-1);
 	nbTeams->visible=false;
 	addWidget(nbTeams);
@@ -418,6 +422,10 @@ void NewMapScreen::onAction(Widget *source, Action action, int par1, int par2)
 						logRepeatAreaTimes->visible=areaTimesText->visible=
 						true;
 						break;
+					case  MapGenerationDescriptor::eCONCRETEISLANDS:
+						break;
+					case  MapGenerationDescriptor::eISLES:
+						break;
 					case  MapGenerationDescriptor::eOLDRANDOM:
 						ratioText->visible=
 						waterRatio->visible=waterText->visible=
