@@ -4,7 +4,7 @@
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
+  the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.
 
   This program is distributed in the hope that it will be useful,
@@ -258,11 +258,8 @@ bool Race::load(GAGCore::InputStream *stream, Sint32 versionMinor)
 	for (int i=0; i<NB_UNIT_TYPE; i++)
 		for(int j=0; j<NB_UNIT_LEVELS; j++)
 			unitTypes[i][j].load(stream, versionMinor);
-	
-	if (versionMinor >= 34)
-		hungryness = (Sint32)stream->readSint32("hungryness");
-	else
-		hungryness = defaultRace.hungryness;
+
+	hungryness = (Sint32)stream->readSint32("hungryness");
 	
 	return true;
 }
