@@ -4,7 +4,7 @@
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
+  the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.
 
   This program is distributed in the hope that it will be useful,
@@ -26,6 +26,8 @@
 #include <Types.h>
 #endif
 
+#include <string>
+
 //! No ressource identifier. This correspond to ressource type 255. On this case, variety, amout and animation are zero.
 #define NO_RES_TYPE 0xFF
 
@@ -42,6 +44,8 @@ struct Ressource
 	Uint32 getUint32() { return animation | (amount<<8) | (variety<<16) | (type<<24); }
 };
 
+std::string getRessourceName(int type);
+
 #define MAX_NB_RESSOURCES 15
 #define MAX_RESSOURCES 8
 #define WOOD 0
