@@ -38,21 +38,16 @@
 #include "boost/lexical_cast.hpp"
 #include "GameGUIKeyActions.h"
 #include "MapEditKeyActions.h"
+#include "FormatableString.h"
 
 SettingsScreen::SettingsScreen()
- : mapeditKeyboardManager(MapEditShortcuts), guiKeyboardManager(GameGUIShortcuts)
+ : Glob2TabScreen(false, true), mapeditKeyboardManager(MapEditShortcuts), guiKeyboardManager(GameGUIShortcuts)
 {
 	old_settings=globalContainer->settings;
-	//following are standard choices for all screens
-	//tab choices
-	generalsettings=new TextButton( 10, 10, 200, 40, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "menu", Toolkit::getStringTable()->getString("[general settings]"), GENERALSETTINGS);
-	addWidget(generalsettings);
-
-	unitsettings=new TextButton( 220, 10, 200, 40, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "menu", Toolkit::getStringTable()->getString("[unit settings]"), UNITSETTINGS);
-	addWidget(unitsettings);
-
-	keyboardsettings=new TextButton( 430, 10, 200, 40, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "menu", Toolkit::getStringTable()->getString("[keyboard settings]"), KEYBOARDSETTINGS);
-	addWidget(keyboardsettings);
+	
+	generalGroup = addGroup(Toolkit::getStringTable()->getString("[general settings]"));
+	unitGroup = addGroup(Toolkit::getStringTable()->getString("[building settings]"));
+	keyboardGroup = addGroup(Toolkit::getStringTable()->getString("[keyboard settings]"));
 
 	// Screen entry/quit part
 	ok=new TextButton( 230, 420, 180, 40, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "menu", Toolkit::getStringTable()->getString("[ok]"), OK);
@@ -63,7 +58,7 @@ SettingsScreen::SettingsScreen()
 	//following are all general settings
 	// language part
 	language=new Text(20, 60, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "standard", Toolkit::getStringTable()->getString("[language-tr]"));
-	addWidget(language);
+	addWidgetToGroup(language, generalGroup);
 	languageList=new List(20, 90, 180, 200, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "standard");
 	for (int i=0; i<Toolkit::getStringTable()->getNumberOfLanguage(); i++)
 	{
@@ -72,16 +67,18 @@ SettingsScreen::SettingsScreen()
 		else
 			languageList->addText(Toolkit::getStringTable()->getStringInLang("[language]", i));
 	}
-	addWidget(languageList);
+	addWidgetToGroup(languageList, generalGroup);
 
 	// graphics part
 	display=new Text(230, 60, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "standard", Toolkit::getStringTable()->getString("[display]"));
-	addWidget(display);
+	addWidgetToGroup(display, generalGroup);
 	actDisplay = new Text(440, 60, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "standard", actDisplayModeToString().c_str());
-	addWidget(actDisplay);
-	modeList=new List(440, 90, 180, 200, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "standard");
+	addWidgetToGroup(actDisplay, generalGroup);
+	modeList=new List(440, 90, 180, 190, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "standard");
 	globalContainer->gfx->beginVideoModeListing();
 	int w, h;
+	const int standardResolutionsCount=5;
+	int standardResolutions[standardResolutionsCount][2]={{640,480},{800,600},{1024,768},{1280,1024},{1600,1200}};
 	while(globalContainer->gfx->getNextVideoMode(&w, &h))
 	{
 		std::ostringstream ost;
@@ -89,43 +86,55 @@ SettingsScreen::SettingsScreen()
 		if (!modeList->isText(ost.str().c_str()))
 			modeList->addText(ost.str().c_str());
 	}
-	addWidget(modeList);
+	for(int i=0; i<standardResolutionsCount; i++)
+	{
+		std::ostringstream ost;
+		ost << standardResolutions[i][0] << "x" << standardResolutions[i][1];
+		if (!modeList->isText(ost.str().c_str()))
+		{
+			ost << " *";
+			modeList->addText(ost.str().c_str());
+		}
+		
+	}
+	addWidgetToGroup(modeList, generalGroup);
+	modeListNote=new Text(modeList->getLeft(), modeList->getTop()+modeList->getHeight(), ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "standard", Toolkit::getStringTable()->getString("[no fullscreen]"));
+	addWidgetToGroup(modeListNote, generalGroup);
 	
 	fullscreen=new OnOffButton(230, 90, 20, 20, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, globalContainer->settings.screenFlags & GraphicContext::FULLSCREEN, FULLSCREEN);
-	addWidget(fullscreen);
+	addWidgetToGroup(fullscreen, generalGroup);
 	fullscreenText=new Text(260, 90, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "standard", Toolkit::getStringTable()->getString("[fullscreen]"), 180);
-	addWidget(fullscreenText);
+	addWidgetToGroup(fullscreenText, generalGroup);
 	
 	#ifdef HAVE_OPENGL
 	#endif
 	usegpu=new OnOffButton(230, 90 + 30, 20, 20, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, globalContainer->settings.screenFlags & GraphicContext::USEGPU, USEGL);
-	addWidget(usegpu);
-	usegpuText=new Text(260, 90 + 30, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "standard", "OpenGL", 180);
-	addWidget(usegpuText);
+	addWidgetToGroup(usegpu, generalGroup);
+	usegpuText=new Text(260, 90 + 30, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "standard", Toolkit::getStringTable()->getString("[OpenGL]"), 180);
+	addWidgetToGroup(usegpuText, generalGroup);
 	
 	lowquality=new OnOffButton(230, 90 + 60, 20, 20, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, globalContainer->settings.optionFlags & GlobalContainer::OPTION_LOW_SPEED_GFX, LOWQUALITY);
-	addWidget(lowquality);
+	addWidgetToGroup(lowquality, generalGroup);
 	lowqualityText=new Text(260, 90 + 60, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "standard", Toolkit::getStringTable()->getString("[lowquality]"), 180);
-	addWidget(lowqualityText);
+	addWidgetToGroup(lowqualityText, generalGroup);
 
 	customcur=new OnOffButton(230, 90 + 90, 20, 20, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, globalContainer->settings.screenFlags & GraphicContext::CUSTOMCURSOR, CUSTOMCUR);
-	addWidget(customcur);
+	addWidgetToGroup(customcur, generalGroup);
 	customcurText=new Text(260, 90 + 90, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "standard", Toolkit::getStringTable()->getString("[customcur]"), 180);
-	addWidget(customcurText);
+	addWidgetToGroup(customcurText, generalGroup);
 	rememberUnitButton=new OnOffButton(230, 90 + 120, 20, 20, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, globalContainer->settings.rememberUnit, REMEMBERUNIT);
-	addWidget(rememberUnitButton);
+	addWidgetToGroup(rememberUnitButton, generalGroup);
 	rememberUnitText=new Text(260, 90 + 120, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "standard", Toolkit::getStringTable()->getString("[remember unit]"), 180);
-	addWidget(rememberUnitText);
+	addWidgetToGroup(rememberUnitText, generalGroup);
 
 	scrollwheel=new OnOffButton(230, 90 + 150, 20, 20, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, globalContainer->settings.scrollWheelEnabled, SCROLLWHEEL);
-	addWidget(scrollwheel);
+	addWidgetToGroup(scrollwheel, generalGroup);
 	scrollwheelText=new Text(260, 90 + 150, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "standard", Toolkit::getStringTable()->getString("[scroll wheel enabled]"), 180);
-	addWidget(scrollwheelText);
-
-
+	addWidgetToGroup(scrollwheelText, generalGroup);
 
 	
 	rebootWarning=new Text(0, 300, ALIGN_FILL, ALIGN_SCREEN_CENTERED, "standard", Toolkit::getStringTable()->getString("[Warning, you need to reboot the game for changes to take effect]"));
+	//TODO: warning style should be defined centrally.
 	rebootWarning->setStyle(Font::Style(Font::STYLE_BOLD, 255, 60, 60));
 	addWidget(rebootWarning);
 	
@@ -134,37 +143,30 @@ SettingsScreen::SettingsScreen()
 
 	// Username part
 	userName=new TextInput(20, 360, 180, 25, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "standard", globalContainer->getUsername(), true, 32);
-	addWidget(userName);
+	addWidgetToGroup(userName, generalGroup);
 	usernameText=new Text(20, 330, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "standard", Toolkit::getStringTable()->getString("[username]"));
-	addWidget(usernameText);
+	addWidgetToGroup(usernameText, generalGroup);
 
 	// Audio part
 	audio=new Text(230, 330, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "standard", Toolkit::getStringTable()->getString("[audio]"), 300);
-	addWidget(audio);
+	addWidgetToGroup(audio, generalGroup);
 	audioMute=new OnOffButton(230, 365, 20, 20, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, globalContainer->settings.mute, MUTE);
-	addWidget(audioMute);
+	addWidgetToGroup(audioMute, generalGroup);
 	audioMuteText=new Text(260, 365, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "standard", Toolkit::getStringTable()->getString("[mute]"), 200);
-	addWidget(audioMuteText);
+	addWidgetToGroup(audioMuteText, generalGroup);
 	musicVol=new Selector(320, 350, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, 180, globalContainer->settings.musicVolume, 256, true);
-	addWidget(musicVol);
+	addWidgetToGroup(musicVol, generalGroup);
 	voiceVol=new Selector(320, 385, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, 180, globalContainer->settings.voiceVolume, 256, true);
-	addWidget(voiceVol);
+	addWidgetToGroup(voiceVol, generalGroup);
 	musicVolText=new Text(320, 330, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "standard", Toolkit::getStringTable()->getString("[Music volume]"), 300);
-	addWidget(musicVolText);
+	addWidgetToGroup(musicVolText, generalGroup);
 	voiceVolText=new Text(320, 365, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "standard", Toolkit::getStringTable()->getString("[Voice volume]"), 300);
-	addWidget(voiceVolText);
+	addWidgetToGroup(voiceVolText, generalGroup);
 	setVisibilityFromAudioSettings();
 	
 	
-	int first_group_row=0;
-	int first_group_current_column_x=20;
-	int first_group_widest_element=0;
-	
-	int second_group_row=1;
-	int second_group_first_row_x=170;
-	int second_group_current_column_x=170;
-	int second_group_widest_element=0;
-	
+
+	//This is all the second tab, the default values for various buildings
 	for(int t=0; t<IntBuildingType::NB_BUILDING; ++t)
 	{
 		for(int l=0; l<6; ++l)
@@ -174,7 +176,11 @@ SettingsScreen::SettingsScreen()
 		}
 	}
 	
-	///First group are completed buildings, Inn, Swarm and Defence tower
+	int group_row=0;
+	int group_current_column_x=20;
+	int group_widest_element=0;
+	
+	//First group is fully constructed buildings sites
 	for(int t=0; t<IntBuildingType::NB_BUILDING; ++t)
 	{
 		if(t==IntBuildingType::EXPLORATION_FLAG || t==IntBuildingType::WAR_FLAG || t==IntBuildingType::CLEARING_FLAG)
@@ -182,101 +188,123 @@ SettingsScreen::SettingsScreen()
 		std::string name=IntBuildingType::typeFromShortNumber(t);
 		for(int l=0; l<3; ++l)
 		{
-			if(globalContainer->buildingsTypes.getByType(name, l, false) != NULL && globalContainer->settings.defaultUnitsAssigned[t][l*2+1]>0)
+			BuildingType* type = globalContainer->buildingsTypes.getByType(name, l, false);
+			if(type != NULL && (type->foodable || type->fillable))
 			{
-				int size = addDefaultUnitAssignmentWidget(t, l*2+1, first_group_current_column_x, 100 + 40*first_group_row, 1);
-				first_group_widest_element = std::max(first_group_widest_element, size);
+				int size = addDefaultUnitAssignmentWidget(t, l*2+1, group_current_column_x, 100 + 40*group_row, 1);
+				group_widest_element = std::max(group_widest_element, size);
 				
-				first_group_row += 1;
-				if(first_group_row == 8)
+				group_row += 1;
+				if(group_row == 4)
 				{
-					first_group_row = 0;
-					first_group_current_column_x += first_group_widest_element;
-					first_group_widest_element = 0;
+					group_row = 0;
+					group_current_column_x += group_widest_element + 10;
+					group_widest_element = 0;
 				}
 			}
 		}	
 	}
 	
-	///Second group, at the top is Swarm, Wall, Market, the rest follow horizontally
-	for(int l=0; l<3; ++l)
+	group_row=0;
+	group_current_column_x=20;
+	group_widest_element=0;	
+	///Second group, new construction
+	for(int t=0; t<IntBuildingType::NB_BUILDING; ++t)
+	{
+		std::string name=IntBuildingType::typeFromShortNumber(t);
+		//Even numbers represent under-construction, whereas odd numbers represent completed buildings		
+		if(globalContainer->buildingsTypes.getByType(name, 0, true) != NULL)
+		{
+			int size = addDefaultUnitAssignmentWidget(t, 0, group_current_column_x, 100 + 40*group_row, 2);
+			group_widest_element = std::max(group_widest_element, size);
+			
+			group_row += 1;
+			if(group_row == 6)
+			{
+				group_row = 0;
+				group_current_column_x += group_widest_element + 10;
+				group_widest_element = 0;
+			}
+		}
+	}
+	
+	///Third group, upgrades
+	group_row=0;
+	group_current_column_x=20;
+	group_widest_element=0;
+	for(int l=1; l<3; ++l)
 	{
 		for(int t=0; t<IntBuildingType::NB_BUILDING; ++t)
 		{
 			std::string name=IntBuildingType::typeFromShortNumber(t);
 			//Even numbers represent under-construction, whereas odd numbers represent completed buildings		
-			if(globalContainer->buildingsTypes.getByType(name, l, true) != NULL && globalContainer->settings.defaultUnitsAssigned[t][l*2]>0)
+			if(globalContainer->buildingsTypes.getByType(name, l, true) != NULL)
 			{
-				int this_row = second_group_row;
-				int this_x = second_group_current_column_x;
-				if(t == IntBuildingType::SWARM_BUILDING || t == IntBuildingType::STONE_WALL || t == IntBuildingType::MARKET_BUILDING)
-				{
-					this_row = 0;
-					this_x = second_group_first_row_x;
-					second_group_first_row_x += 180;
-				}
-				else
-				{
-					second_group_row += 1;
-				}
+				int size = addDefaultUnitAssignmentWidget(t, l*2, group_current_column_x, 100 + 40*group_row, 3);
+				group_widest_element = std::max(group_widest_element, size);
 				
-				int size = addDefaultUnitAssignmentWidget(t, l*2, this_x, 100 + 40*this_row, 1);
-				second_group_widest_element = std::max(second_group_widest_element, size);
-				
-				if(second_group_row == 8)
+				group_row += 1;
+				if(group_row == 7)
 				{
-					second_group_row = 1;
-					second_group_current_column_x += 180;
-					second_group_widest_element = 0;
+					group_row = 0;
+					group_current_column_x += group_widest_element + 10;
+					group_widest_element = 0;
 				}
 			}
 		}
 	}
 	
-	first_group_row=0;
-	first_group_current_column_x=20;
-	first_group_widest_element=0;
-	///On the second screen, the only group is first
+	group_row=0;
+	group_current_column_x=20;
+	group_widest_element=0;
+	///On the fourth screen, flags
 	for(int t=IntBuildingType::EXPLORATION_FLAG; t<=IntBuildingType::CLEARING_FLAG; ++t)
 	{
-		int size = addDefaultUnitAssignmentWidget(t, 1, first_group_current_column_x, 100 + 40*first_group_row, 2, true);
-		first_group_widest_element = std::max(first_group_widest_element, size);
+		int size = addDefaultUnitAssignmentWidget(t, 1, group_current_column_x, 100 + 40*group_row, 4, true);
+		group_widest_element = std::max(group_widest_element, size);
 		
-		first_group_row += 1;
-		if(first_group_row == 8)
+		group_row += 1;
+		if(group_row == 8)
 		{
-			first_group_row = 0;
-			first_group_current_column_x += first_group_widest_element;
-			first_group_widest_element = 0;
+			group_row = 0;
+			group_current_column_x += group_widest_element + 10;
+			group_widest_element = 0;
+		}
+	}
+	flagSettingsExplanation = new Text( 10, 100+40*3+10, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "standard", Toolkit::getStringTable()->getString("[flag settings explanation]"));
+	
+	for(int t=IntBuildingType::EXPLORATION_FLAG; t<=IntBuildingType::CLEARING_FLAG; ++t)
+	{
+		int size = addDefaultFlagRadiusWidget(t, group_current_column_x, 130 + 40*group_row, 4);
+		group_widest_element = std::max(group_widest_element, size);
+		
+		group_row += 1;
+		if(group_row == 8)
+		{
+			group_row = 0;
+			group_current_column_x += group_widest_element + 10;
+			group_widest_element = 0;
 		}
 	}
 	
-	flags = new TextButton( 10, 60, 120, 20, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "standard", Toolkit::getStringTable()->getString("[Building Settings]"), BUILDINGSETTINGS);
-	buildings = new TextButton( 140, 60, 120, 20, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "standard", Toolkit::getStringTable()->getString("[Flag Settings]"), FLAGSETTINGS);
-	
-	unitSettingsExplanation = new Text( 270, 60, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "standard", Toolkit::getStringTable()->getString("[unit settings explanation]"));
-	unitSettingsHeading1 = new Text( 160, 80, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "standard", Toolkit::getStringTable()->getString("[construction and upgrades]"));
-	unitSettingsHeading2 = new Text( 10, 80, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "standard", Toolkit::getStringTable()->getString("[constructed buildings]"));
+	buildings = new TextButton( 10, 60, 120, 20, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "standard", Toolkit::getStringTable()->getString("[Building Defaults]"), BUILDINGSETTINGS);
+	constructionsites = new TextButton( 140, 60, 220, 20, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "standard", Toolkit::getStringTable()->getString("[Construction Site Defaults]"), CONSTRUCTIONSITES);
+	upgrades = new TextButton( 370, 60, 120, 20, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "standard", Toolkit::getStringTable()->getString("[Upgrade Defaults]"), UPGRADES);
+	flags = new TextButton( 500, 60, 120, 20, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "standard", Toolkit::getStringTable()->getString("[Flag Defaults]"), FLAGSETTINGS);
 
+	unitSettingsExplanation = new Text( 10, 80, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "standard", Toolkit::getStringTable()->getString("[unit settings explanation]"));
 
-	unitSettingsExplanation->visible = false;
-	unitSettingsHeading1->visible = false;
-	unitSettingsHeading2->visible = false;
-	buildings->visible = false;
-	flags->visible = false;
+	addWidgetToGroup(unitSettingsExplanation, unitGroup);
+	addWidgetToGroup(buildings, unitGroup);
+	addWidgetToGroup(constructionsites, unitGroup);
+	addWidgetToGroup(upgrades, unitGroup);
+	addWidgetToGroup(flags, unitGroup);
+	addWidgetToGroup(flagSettingsExplanation, unitGroup);
 
-	addWidget(unitSettingsExplanation);
-	addWidget(unitSettingsHeading1);
-	addWidget(unitSettingsHeading2);
-	addWidget(buildings);
-	addWidget(flags);
+	// This is the third tab, the keyboard shortcuts
+	game_shortcuts=new TextButton( 10, 60, 120, 20, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "standard", Toolkit::getStringTable()->getString("[game shortcuts]"), GAMESHORTCUTS);
 
-	//shortcuts part
-	game_shortcuts=new TextButton( 100, 60, 120, 20, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "standard", Toolkit::getStringTable()->getString("[game shortcuts]"), GAMESHORTCUTS);
-	game_shortcuts->visible=false;
-
-	editor_shortcuts=new TextButton( 230, 60, 120, 20, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "standard", Toolkit::getStringTable()->getString("[editor shortcuts]"), EDITORSHORTCUTS);
-	editor_shortcuts->visible=false;
+	editor_shortcuts=new TextButton( 140, 60, 120, 20, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "standard", Toolkit::getStringTable()->getString("[editor shortcuts]"), EDITORSHORTCUTS);
 
 	shortcut_list = new List(20, 110, 325, 160, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "standard");
 	action_list = new List(365, 110 , 265, 190, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "standard");
@@ -291,35 +319,23 @@ SettingsScreen::SettingsScreen()
 	pressedUnpressedSelector->clearTexts();
 	pressedUnpressedSelector->addText(Toolkit::getStringTable()->getString("[on press]"));
 	pressedUnpressedSelector->addText(Toolkit::getStringTable()->getString("[on unpress]"));
-
-	
-	game_shortcuts->visible = false;
-	editor_shortcuts->visible = false;
-	restore_default_shortcuts->visible = false;
-	shortcut_list->visible = false;
-	action_list->visible = false;
-	select_key_1->visible = false;
-	key_2_active->visible = false;
-	select_key_2->visible = false;
-	pressedUnpressedSelector->visible = false;
-	add_shortcut->visible = false;
-	remove_shortcut->visible = false;
-	restore_default_shortcuts->visible=false;
 		
-	addWidget(game_shortcuts);
-	addWidget(editor_shortcuts);
-	addWidget(shortcut_list);
-	addWidget(action_list);
-	addWidget(select_key_1);
-	addWidget(key_2_active);
-	addWidget(select_key_2);
-	addWidget(pressedUnpressedSelector);
-	addWidget(add_shortcut);
-	addWidget(remove_shortcut);
-	addWidget(restore_default_shortcuts);
+	addWidgetToGroup(game_shortcuts, keyboardGroup);
+	addWidgetToGroup(editor_shortcuts, keyboardGroup);
+	addWidgetToGroup(shortcut_list, keyboardGroup);
+	addWidgetToGroup(action_list, keyboardGroup);
+	addWidgetToGroup(select_key_1, keyboardGroup);
+	addWidgetToGroup(key_2_active, keyboardGroup);
+	addWidgetToGroup(select_key_2, keyboardGroup);
+	addWidgetToGroup(pressedUnpressedSelector, keyboardGroup);
+	addWidgetToGroup(add_shortcut, keyboardGroup);
+	addWidgetToGroup(remove_shortcut, keyboardGroup);
+	addWidgetToGroup(restore_default_shortcuts, keyboardGroup);
 
 	currentMode = GameGUIShortcuts;
 
+	activateGroup(generalGroup);
+
 	gfxAltered = false;
 }
 
@@ -333,8 +349,21 @@ void SettingsScreen::addNumbersFor(int low, int high, Number* widget)
 }
 
 
+void SettingsScreen::setFullscreen()
+{
+    if(fullscreen->getState()){
+        globalContainer->settings.screenFlags |= GraphicContext::FULLSCREEN;
+        globalContainer->settings.screenFlags &= ~(GraphicContext::RESIZABLE);
+    }else{
+        globalContainer->settings.screenFlags &= ~(GraphicContext::FULLSCREEN);
+        globalContainer->settings.screenFlags |= GraphicContext::RESIZABLE;
+    }
+    updateGfxCtx();
+}
+
 void SettingsScreen::onAction(Widget *source, Action action, int par1, int par2)
 {
+	TabScreen::onAction(source, action, par1, par2);
 	if ((action==BUTTON_RELEASED) || (action==BUTTON_SHORTCUT))
 	{
 		if (par1==OK)
@@ -359,189 +388,6 @@ void SettingsScreen::onAction(Widget *source, Action action, int par1, int par2)
 
 			endExecute(par1);
 		}
-		else if (par1==GENERALSETTINGS)	
-		{
-			language->visible=true;
-			languageList->visible=true;
-			display->visible=true;
-			actDisplay->visible=true;
-			modeList->visible=true;
-			fullscreen->visible=true;
-			fullscreenText->visible=true;
-			usegpu->visible=true;
-			usegpuText->visible=true;
-			lowquality->visible=true;
-			lowqualityText->visible=true;
-			customcur->visible=true;
-			customcurText->visible=true;
-			userName->visible=true;
-			usernameText->visible=true;
-			audio->visible=true;
-			audioMuteText->visible=true;
-			audioMute->visible=true;
-			musicVol->visible=true;
-			musicVolText->visible=true;
-			voiceVol->visible=true;
-			voiceVolText->visible=true;
-			rememberUnitButton->visible=true;
-			rememberUnitText->visible=true;
-			scrollwheel->visible=true;
-			scrollwheelText->visible=true;
-			
-			
-			for(int t=0; t<IntBuildingType::NB_BUILDING; ++t)
-			{
-				for(int l=0; l<6; ++l)
-				{
-					if(unitRatios[t][l])
-					{
-						unitRatios[t][l]->visible=false;
-						unitRatioTexts[t][l]->visible=false;
-					}
-				}
-			}
-			
-			
-			unitSettingsExplanation->visible=false;
-			unitSettingsHeading1->visible=false;
-			unitSettingsHeading2->visible=false;
-			buildings->visible=false;
-			flags->visible=false;
-			
-			game_shortcuts->visible=false;
-			editor_shortcuts->visible=false;
-			select_key_1->visible=false;
-			key_2_active->visible=false;
-			select_key_2->visible=false;
-			pressedUnpressedSelector->visible=false;
-			shortcut_list->visible=false;
-			action_list->visible=false;
-			add_shortcut->visible=false;
-			remove_shortcut->visible=false;
-			restore_default_shortcuts->visible=false;
-			setVisibilityFromAudioSettings();
-		}
-
-		
-		else if (par1==UNITSETTINGS)
-		{
-			language->visible=false;
-			languageList->visible=false;
-			display->visible=false;
-			actDisplay->visible=false;
-			modeList->visible=false;
-			fullscreen->visible=false;
-			fullscreenText->visible=false;
-			usegpu->visible=false;
-			usegpuText->visible=false;
-			lowquality->visible=false;
-			lowqualityText->visible=false;
-			customcur->visible=false;
-			customcurText->visible=false;
-			userName->visible=false;
-			usernameText->visible=false;
-			audio->visible=false;
-			audioMuteText->visible=false;
-			audioMute->visible=false;
-			musicVol->visible=false;
-			musicVolText->visible=false;
-			voiceVol->visible=false;
-			voiceVolText->visible=false;
-			rememberUnitButton->visible=false;
-			rememberUnitText->visible=false;
-			scrollwheel->visible=false;
-			scrollwheelText->visible=false;
-			
-			activateDefaultAssignedGroupNumber(1);
-			
-			unitSettingsExplanation->visible=true;
-			unitSettingsHeading1->visible=true;
-			unitSettingsHeading2->visible=true;
-			buildings->visible=true;
-			flags->visible=true;
-	
-			game_shortcuts->visible=false;
-			editor_shortcuts->visible=false;
-			select_key_1->visible=false;
-			key_2_active->visible=false;
-			select_key_2->visible=false;
-			pressedUnpressedSelector->visible=false;
-			shortcut_list->visible=false;
-			action_list->visible=false;
-			add_shortcut->visible=false;
-			remove_shortcut->visible=false;
-			restore_default_shortcuts->visible=false;
-		}
-
-		else if (par1==KEYBOARDSETTINGS)
-		{
-			language->visible=false;
-			languageList->visible=false;
-			display->visible=false;
-			actDisplay->visible=false;
-			modeList->visible=false;
-			fullscreen->visible=false;
-			fullscreenText->visible=false;
-			usegpu->visible=false;
-			usegpuText->visible=false;
-			lowquality->visible=false;
-			lowqualityText->visible=false;
-			customcur->visible=false;
-			customcurText->visible=false;
-			userName->visible=false;
-			usernameText->visible=false;
-			audio->visible=false;
-			audioMuteText->visible=false;
-			audioMute->visible=false;
-			musicVol->visible=false;
-			musicVolText->visible=false;
-			voiceVol->visible=false;
-			voiceVolText->visible=false;
-			rememberUnitButton->visible=false;
-			rememberUnitText->visible=false;
-			scrollwheel->visible=false;
-			scrollwheelText->visible=false;
-			
-			
-			for(int t=0; t<IntBuildingType::NB_BUILDING; ++t)
-			{
-				for(int l=0; l<6; ++l)
-				{
-					if(unitRatios[t][l])
-					{
-						unitRatios[t][l]->visible=false;
-						unitRatioTexts[t][l]->visible=false;
-					}
-				}
-			}
-			
-			
-			unitSettingsExplanation->visible=false;
-			unitSettingsHeading1->visible=false;
-			unitSettingsHeading2->visible=false;
-			buildings->visible=false;
-			flags->visible=false;
-	
-			game_shortcuts->visible=true;
-			editor_shortcuts->visible=true;
-			select_key_1->visible=true;
-			key_2_active->visible=true;
-			select_key_2->visible=true;
-			pressedUnpressedSelector->visible=true;
-			shortcut_list->visible=true;
-			action_list->visible=true;
-			add_shortcut->visible=true;
-			remove_shortcut->visible=true;
-			restore_default_shortcuts->visible=true;
-			currentMode = GameGUIShortcuts;
-			updateShortcutList();
-			if(shortcut_list->getCount() == 0)
-				shortcut_list->setSelectionIndex(-1);
-			else
-				shortcut_list->setSelectionIndex(0);
-			updateActionList();
-			updateShortcutInfoFromSelection();
-		}
 		else if (par1==RESTOREDEFAULTSHORTCUTS)
 		{
 			loadDefaultKeyboardShortcuts();
@@ -582,14 +428,18 @@ void SettingsScreen::onAction(Widget *source, Action action, int par1, int par2)
 		else if(par1==BUILDINGSETTINGS)
 		{
 			activateDefaultAssignedGroupNumber(1);
-			unitSettingsHeading1->visible=true;
-			unitSettingsHeading2->visible=true;
+		}
+		else if(par1==CONSTRUCTIONSITES)
+		{
+			activateDefaultAssignedGroupNumber(2);
+		}
+		else if(par1==UPGRADES)
+		{
+			activateDefaultAssignedGroupNumber(3);
 		}
 		else if(par1==FLAGSETTINGS)
 		{
-			activateDefaultAssignedGroupNumber(2);
-			unitSettingsHeading1->visible=false;
-			unitSettingsHeading2->visible=false;
+			activateDefaultAssignedGroupNumber(4);
 		}
 	}
 	else if (action==NUMBER_ELEMENT_SELECTED)
@@ -606,6 +456,13 @@ void SettingsScreen::onAction(Widget *source, Action action, int par1, int par2)
 				}
 			}
 		}
+		for(int t=0; t<3; ++t)
+		{
+			if(flagRadii[t])
+			{
+				globalContainer->settings.defaultFlagRadius[t] = flagRadii[t]->getNth()+1;
+			}
+		}
 	}
 	else if (action==LIST_ELEMENT_SELECTED)
 	{
@@ -615,18 +472,18 @@ void SettingsScreen::onAction(Widget *source, Action action, int par1, int par2)
 			ok->setText(Toolkit::getStringTable()->getString("[ok]"));
 			cancel->setText(Toolkit::getStringTable()->getString("[Cancel]"));
 
-//;			title->setText(Toolkit::getStringTable()->getString("[settings]"));
+			modifyTitle(generalGroup, Toolkit::getStringTable()->getString("[general settings]"));
+			modifyTitle(unitGroup, Toolkit::getStringTable()->getString("[building settings]"));
+			modifyTitle(keyboardGroup, Toolkit::getStringTable()->getString("[keyboard settings]"));
+
+			modeListNote->setText(Toolkit::getStringTable()->getString("[no fullscreen]"));
 			language->setText(Toolkit::getStringTable()->getString("[language-tr]"));
 			display->setText(Toolkit::getStringTable()->getString("[display]"));
 			usernameText->setText(Toolkit::getStringTable()->getString("[username]"));
 			audio->setText(Toolkit::getStringTable()->getString("[audio]"));
 
-			generalsettings->setText(Toolkit::getStringTable()->getString("[general settings]"));
-			unitsettings->setText(Toolkit::getStringTable()->getString("[unit settings]"));
-			keyboardsettings->setText(Toolkit::getStringTable()->getString("[keyboard settings]"));
-
 			fullscreenText->setText(Toolkit::getStringTable()->getString("[fullscreen]"));
-			//usegpuText->setText(Toolkit::getStringTable()->getString("[opengl]"));
+			usegpuText->setText(Toolkit::getStringTable()->getString("[OpenGL]"));
 			lowqualityText->setText(Toolkit::getStringTable()->getString("[lowquality]"));
 			customcurText->setText(Toolkit::getStringTable()->getString("[customcur]"));
 
@@ -640,10 +497,10 @@ void SettingsScreen::onAction(Widget *source, Action action, int par1, int par2)
 			rebootWarning->setText(Toolkit::getStringTable()->getString("[Warning, you need to reboot the game for changes to take effect]"));
 			
 			unitSettingsExplanation->setText(Toolkit::getStringTable()->getString("[unit settings explanation]"));
-			unitSettingsHeading1->setText(Toolkit::getStringTable()->getString("[construction and upgrades]"));
-			unitSettingsHeading2->setText(Toolkit::getStringTable()->getString("[constructed buildings]"));
-			buildings->setText(Toolkit::getStringTable()->getString("[Building Settings]"));
-			flags->setText(Toolkit::getStringTable()->getString("[Flag Settings]"));
+			buildings->setText(Toolkit::getStringTable()->getString("[Building Defaults]"));
+			flags->setText(Toolkit::getStringTable()->getString("[Flag Defaults]"));
+			constructionsites->setText(Toolkit::getStringTable()->getString("[Construction Site Defaults]"));
+			upgrades->setText(Toolkit::getStringTable()->getString("[Upgrade Defaults]"));
 			setLanguageTextsForDefaultAssignmentWidgets();
 			
 			game_shortcuts->setText(Toolkit::getStringTable()->getString("[game shortcuts]"));
@@ -659,10 +516,22 @@ void SettingsScreen::onAction(Widget *source, Action action, int par1, int par2)
 		else if (source==modeList)
 		{
 			int w, h;
-			sscanf(modeList->getText(par1).c_str(), "%dx%d", &w, &h);
+			char fso; //full screen only
+			sscanf(modeList->getText(par1).c_str(), "%dx%d %c", &w, &h, &fso);
 			globalContainer->settings.screenWidth=w;
 			globalContainer->settings.screenHeight=h;
-			updateGfxCtx();
+			if(fso=='*')
+			{
+				fullscreen->setState(false);
+				fullscreen->setClickable(false);
+				modeListNote->setStyle(Font::Style(Font::STYLE_BOLD, 255, 60, 60));
+			}
+			else
+			{
+				fullscreen->setClickable(true);
+				modeListNote->setStyle(Font::Style(Font::STYLE_NORMAL, 255, 255, 255));
+			}
+		    setFullscreen();
 		}
 		else if (source == shortcut_list)
 		{
@@ -695,17 +564,7 @@ void SettingsScreen::onAction(Widget *source, Action action, int par1, int par2)
 		}
 		else if (source==fullscreen)
 		{
-			if (fullscreen->getState())
-			{
-				globalContainer->settings.screenFlags |= GraphicContext::FULLSCREEN;
-				globalContainer->settings.screenFlags &= ~(GraphicContext::RESIZABLE);
-			}
-			else
-			{
-				globalContainer->settings.screenFlags &= ~(GraphicContext::FULLSCREEN);
-				globalContainer->settings.screenFlags |= GraphicContext::RESIZABLE;
-			}
-			updateGfxCtx();
+		    setFullscreen();
 		}
 		else if (source==usegpu)
 		{
@@ -799,12 +658,12 @@ int SettingsScreen::addDefaultUnitAssignmentWidget(int type, int level, int x, i
 	addNumbersFor(0, 20, unitRatios[type][level]);
 	unitRatios[type][level]->setNth(globalContainer->settings.defaultUnitsAssigned[type][level]);
 	unitRatios[type][level]->visible=false;
-	addWidget(unitRatios[type][level]);
+	addWidgetToGroup(unitRatios[type][level], unitGroup);
 
 	std::string text=getDefaultUnitAssignmentText(type, level, flag);
 	unitRatioTexts[type][level]=new Text(x, y, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "standard", text);
 	
-	addWidget(unitRatioTexts[type][level]);
+	addWidgetToGroup(unitRatioTexts[type][level], unitGroup);
 	unitRatioTexts[type][level]->visible=false;
 	unitRatioGroupNumbers[type][level] = group;
 
@@ -813,22 +672,50 @@ int SettingsScreen::addDefaultUnitAssignmentWidget(int type, int level, int x, i
 
 
 
+int SettingsScreen::addDefaultFlagRadiusWidget(int type, int x, int y, int group)
+{
+	int n = type - IntBuildingType::EXPLORATION_FLAG;
+	flagRadii[n] = new Number(x, y+20, 100, 18, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, 20, "menu");
+	addNumbersFor(1, 20, flagRadii[n]);
+	flagRadii[n]->setNth(globalContainer->settings.defaultFlagRadius[n]-1);
+	flagRadii[n]->visible=false;
+	addWidgetToGroup(flagRadii[n], unitGroup);
+
+	std::string text=getDefaultUnitAssignmentText(type, 1, true);
+	flagRadiusTexts[n]=new Text(x, y, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "standard", text);
+	
+	addWidgetToGroup(flagRadiusTexts[n], unitGroup);
+	flagRadiusTexts[n]->visible=false;
+	flagRadiusGroupNumbers[n] = group;
+
+	return std::max(flagRadiusTexts[n]->getWidth(), flagRadii[n]->getWidth());
+}
+
+
+
 std::string SettingsScreen::getDefaultUnitAssignmentText(int type, int level, bool flag)
 {
-	std::string name=IntBuildingType::typeFromShortNumber(type);
+	std::string name="[" + IntBuildingType::typeFromShortNumber(type) + "]";
+	std::string tname = Toolkit::getStringTable()->getString(name.c_str());
 
-	std::string keyname="[";
+	std::string value;
 	if(flag)
 	{
-		keyname+=name + "]";
+		value = tname;
+	}
+	else if(level%2 == 0)
+	{
+		value = FormatableString(Toolkit::getStringTable()->getString("[build %0 level %1]")).arg(tname).arg(level/2 + 1);
+	}
+	else if(level == 1 && globalContainer->buildingsTypes.getByType(IntBuildingType::typeFromShortNumber(type), level+1, false) == NULL)
+	{
+		value = tname;
 	}
 	else
 	{
-		if((level+1)%2)
-			keyname+="build ";
-		keyname+=name + " level " + boost::lexical_cast<std::string>(level/2) + "]";
+		value = FormatableString(Toolkit::getStringTable()->getString("[%0 level %1]")).arg(tname).arg(level/2+1);
 	}
-	return Toolkit::getStringTable()->getString(keyname.c_str());
+	return value;
 }
 
 
@@ -848,6 +735,13 @@ void SettingsScreen::setLanguageTextsForDefaultAssignmentWidgets()
 			}
 		}
 	}
+	for(int t=0; t<3; ++t)
+	{
+		if(flagRadiusTexts[t])
+		{
+			flagRadiusTexts[t]->setText(getDefaultUnitAssignmentText(t+IntBuildingType::EXPLORATION_FLAG, 1, true));
+		}
+	}
 }
 
 
@@ -874,9 +768,53 @@ void SettingsScreen::activateDefaultAssignedGroupNumber(int group)
 			}
 		}
 	}
+	for(int i=0; i<3; ++i)
+	{
+
+		if(flagRadiusGroupNumbers[i] == group)
+		{
+			if(flagRadii[i])
+				flagRadii[i]->visible=true;
+			if(flagRadiusTexts[i])
+				flagRadiusTexts[i]->visible=true;
+		}
+		else
+		{
+			if(flagRadii[i])
+				flagRadii[i]->visible=false;
+			if(flagRadiusTexts[i])
+				flagRadiusTexts[i]->visible=false;
+		}
+	}
+	if(group == 4)
+		flagSettingsExplanation->visible=true;
+	else
+		flagSettingsExplanation->visible=false;
 }
 
 
+void SettingsScreen::onGroupActivated(int group_n)
+{
+	if(group_n == generalGroup)
+	{
+		setVisibilityFromAudioSettings();
+	}
+	else if(group_n == unitGroup)
+	{
+		activateDefaultAssignedGroupNumber(1);
+	}
+	else if(group_n == keyboardGroup)
+	{
+		currentMode = GameGUIShortcuts;
+		updateShortcutList();
+		if(shortcut_list->getCount() == 0)
+			shortcut_list->setSelectionIndex(-1);
+		else
+			shortcut_list->setSelectionIndex(0);
+		updateActionList();
+		updateShortcutInfoFromSelection();
+	}
+}
 
 void SettingsScreen::updateShortcutList(int an)
 {
@@ -1077,3 +1015,4 @@ int SettingsScreen::menu(void)
 {
 	return SettingsScreen().execute(globalContainer->gfx, 30);
 }
+	std::string value;
