@@ -41,7 +41,7 @@ namespace GAGGUI
 	class Number;
 }
 
-class SettingsScreen : public Glob2Screen
+class SettingsScreen : public Glob2TabScreen
 {
 public:
 	enum
@@ -66,16 +66,19 @@ public:
 		REMOVESHORTCUT=17,
 		SCROLLWHEEL=18,
 		BUILDINGSETTINGS=19,
-		FLAGSETTINGS=20,
+		CONSTRUCTIONSITES=20,
+		UPGRADES=21,
+		FLAGSETTINGS=22,
 	};
 private:
 	Settings old_settings;
 	List *languageList;
 	List *modeList;
+	Text *modeListNote;
 	TextInput *userName;
 	
-	TextButton *ok, *cancel, *generalsettings, *unitsettings, *keyboardsettings;
-	TextButton *buildings, *flags;
+	TextButton *ok, *cancel;
+	TextButton *buildings, *flags, *constructionsites, *upgrades;
 	OnOffButton *fullscreen, *usegpu, *lowquality, *customcur, *scrollwheel;
 	Selector *musicVol;
 	Selector *voiceVol;
@@ -83,6 +86,9 @@ private:
 	Number* unitRatios[IntBuildingType::NB_BUILDING][6];
 	Text* unitRatioTexts[IntBuildingType::NB_BUILDING][6];
 	int unitRatioGroupNumbers[IntBuildingType::NB_BUILDING][6];
+	Number* flagRadii[3];
+	Text* flagRadiusTexts[3];
+	int flagRadiusGroupNumbers[3];
 //	Text *title;
 	Text *language, *display, *usernameText, *audio;
 	Text *fullscreenText, *usegpuText, *lowqualityText, *customcurText, *musicVolText, *audioMuteText, *voiceVolText, *rememberUnitText, *scrollwheelText;
@@ -105,8 +111,7 @@ private:
 	TextButton* remove_shortcut;
 	
 	Text* unitSettingsExplanation;
-	Text* unitSettingsHeading1;
-	Text* unitSettingsHeading2;
+	Text* flagSettingsExplanation;
 	
 	bool gfxAltered;
 	
@@ -118,16 +123,23 @@ private:
 	void updateGfxCtx(void);
 	//! Return a string representing the actual display mode
 	std::string actDisplayModeToString(void);
-
+	///processes a potential change in the selected fullscreen state
+	void setFullscreen(void);
 
 	///Holds the keyboard layout for the map editor
 	KeyboardManager mapeditKeyboardManager;
 	///Holds the keyboard layout for the game gui
 	KeyboardManager guiKeyboardManager;
 public:
+	int generalGroup;
+	int unitGroup;
+	int keyboardGroup;
+
 	ShortcutMode currentMode;
 	///Quick code that adds in a default unit assignment widget pair at the specific position, and returns the width.
 	int addDefaultUnitAssignmentWidget(int type, int level, int x, int y, int group, bool flag=false);
+	///Quick code that adds in a default flag radius widget pair at the specific position, and returns the width.
+	int addDefaultFlagRadiusWidget(int type, int x, int y, int group);
 	///Activates the given group number for default assignment widgets
 	void activateDefaultAssignedGroupNumber(int group);
 	///Returns the default unit assignment text
@@ -135,6 +147,9 @@ public:
 	///Sets the texts for all default unit assignment widgets
 	void setLanguageTextsForDefaultAssignmentWidgets();
 	
+	
+	virtual void onGroupActivated(int group_n);
+	
 	///Update shortcut_list, if n is not -1, just update that specific entry
 	void updateShortcutList(int n=-1);
 	///Update the action_list
