@@ -284,19 +284,20 @@ void TeamStats::step(Team *team, bool reloaded)
 		stat.totalNeededPerLevel[k]=maxStat.totalNeededPerLevel[k];
 }
 
-void TeamStats::drawText(int pos)
+void TeamStats::drawText(int posx, int posy)
 {
 	// local variable to speed up access
 	GraphicContext *gfx=globalContainer->gfx;
 	Font *font=globalContainer->littleFont;
 	StringTable *strings=Toolkit::getStringTable();
-	int textStartPosX=gfx->getW()-124;
-	int textStartPosY=pos;
+	int textStartPosX=posx+4;
+	int textStartPosY=posy;
 	
 	TeamStat &newStats=stats[statsIndex];
 	
 	// general
-	gfx->drawString(textStartPosX, textStartPosY, font, strings->getString("[Statistics]"));
+	//gfx->drawString(textStartPosX, textStartPosY, font, strings->getString("[Statistics]"));
+	textStartPosY -= 5; // this is to correct for the removal of the title
 	gfx->drawString(textStartPosX, textStartPosY+15, font, FormatableString("%0 %1").arg(newStats.totalUnit).arg(strings->getString("[Units]")).c_str());
 	if (newStats.totalUnit)
 	{
@@ -347,7 +348,7 @@ void TeamStats::drawText(int pos)
 	}
 }
 
-void TeamStats::drawStat(int pos)
+void TeamStats::drawStat(int posx, int posy)
 {
 	assert(STATS_SIZE==128);// We have graphical constraints
 	
@@ -355,8 +356,8 @@ void TeamStats::drawStat(int pos)
 	GraphicContext *gfx=globalContainer->gfx;
 	Font *font=globalContainer->littleFont;
 	StringTable *strings=Toolkit::getStringTable();
-	int textStartPos=gfx->getW()-124;
-	int startPoxY=pos;
+	int textStartPos=posx+4;
+	int startPoxY=posy;
 	
 	// compute total units
 	/*int maxUnit=0;
@@ -376,8 +377,9 @@ void TeamStats::drawStat(int pos)
 
 	// captions
 	{
-		gfx->drawString(textStartPos, startPoxY, font, strings->getString("[Statistics]"));
-
+		//gfx->drawString(textStartPos, startPoxY, font, strings->getString("[Statistics]"));
+		startPoxY -= 10; // this is to correct for the removal of the title
+		
 		int dec=0;
 		const char *Total=strings->getString("[Total]");
 		const char *free=strings->getString("[free]");
@@ -457,9 +459,9 @@ void TeamStats::drawStat(int pos)
 		int nbSeeking=(seeking*64)/maxWorker;
 		int nbTotal=(stats[index].numberUnitPerType[WORKER]*64)/maxWorker;
 		
-		globalContainer->gfx->drawVertLine(globalContainer->gfx->getW()-128+i, startPoxY+ 36 +64-nbTotal, nbTotal-nbFree-nbSeeking, 34, 66, 163);
-		globalContainer->gfx->drawVertLine(globalContainer->gfx->getW()-128+i, startPoxY+ 36 +64-nbFree-nbSeeking, nbFree, 22, 229, 40);
-		globalContainer->gfx->drawVertLine(globalContainer->gfx->getW()-128+i, startPoxY+ 36 +64-nbSeeking, nbSeeking, 150, 50, 50);
+		globalContainer->gfx->drawVertLine(posx+i, startPoxY+ 36 +64-nbTotal, nbTotal-nbFree-nbSeeking, 34, 66, 163);
+		globalContainer->gfx->drawVertLine(posx+i, startPoxY+ 36 +64-nbFree-nbSeeking, nbFree, 22, 229, 40);
+		globalContainer->gfx->drawVertLine(posx+i, startPoxY+ 36 +64-nbSeeking, nbSeeking, 150, 50, 50);
 
 		int nbOk, nbNeedFood, nbNeedFoodCritical, nbNeedHeal;
 		if (stats[index].totalUnit)
@@ -497,10 +499,10 @@ void TeamStats::drawStat(int pos)
 		{
 			nbOk=nbNeedFood=nbNeedHeal=nbNeedFoodCritical=0;
 		}
-		globalContainer->gfx->drawVertLine(globalContainer->gfx->getW()-128+i, startPoxY+ 120+12  +64-nbNeedHeal-nbNeedFoodCritical-nbNeedFood-nbOk, nbOk, 22, 229, 40);
-		globalContainer->gfx->drawVertLine(globalContainer->gfx->getW()-128+i, startPoxY+ 120+12 +64-nbNeedHeal-nbNeedFoodCritical-nbNeedFood, nbNeedFood, 224, 210, 17);
-		globalContainer->gfx->drawVertLine(globalContainer->gfx->getW()-128+i, startPoxY+ 120+12 +64-nbNeedHeal-nbNeedFoodCritical, nbNeedFoodCritical, 249, 167, 14);
-		globalContainer->gfx->drawVertLine(globalContainer->gfx->getW()-128+i, startPoxY+ 120+12 +64-nbNeedHeal, nbNeedHeal, 250, 25, 25);
+		globalContainer->gfx->drawVertLine(posx+i, startPoxY+ 120+12  +64-nbNeedHeal-nbNeedFoodCritical-nbNeedFood-nbOk, nbOk, 22, 229, 40);
+		globalContainer->gfx->drawVertLine(posx+i, startPoxY+ 120+12 +64-nbNeedHeal-nbNeedFoodCritical-nbNeedFood, nbNeedFood, 224, 210, 17);
+		globalContainer->gfx->drawVertLine(posx+i, startPoxY+ 120+12 +64-nbNeedHeal-nbNeedFoodCritical, nbNeedFoodCritical, 249, 167, 14);
+		globalContainer->gfx->drawVertLine(posx+i, startPoxY+ 120+12 +64-nbNeedHeal, nbNeedHeal, 250, 25, 25);
 	}
 }
 
