@@ -184,7 +184,6 @@ void Unit::load(GAGCore::InputStream *stream, Team *owner, Sint32 versionMinor)
 	else
 		underAttackTimer = 0;
 
-
 	// trigger parameters
 	hp = stream->readSint32("hp");
 	trigHP = stream->readSint32("trigHP");
@@ -467,7 +466,7 @@ void Unit::syncStep(void)
 				degats=1;
 			enemy->hp-=degats;
 			
-			enemy->underAttackTimer = 256/speed + 1;
+			enemy->underAttackTimer = 240;
 
 			boost::shared_ptr<GameEvent> event(new UnitUnderAttackEvent(owner->game->stepCounter, enemy->posX, enemy->posY, enemy->typeNum));
 			enemy->owner->pushGameEvent(event);
@@ -487,7 +486,7 @@ void Unit::syncStep(void)
 					degats=1;
 				enemy->hp-=degats;
 			
-				enemy->underAttackTimer = 256/speed + 1;
+				enemy->underAttackTimer = 240;
 
 				boost::shared_ptr<GameEvent> event(new BuildingUnderAttackEvent(owner->game->stepCounter, enemy->posX, enemy->posY, enemy->shortTypeNum));
 				enemy->owner->pushGameEvent(event);
@@ -583,7 +582,11 @@ bool Unit::isUnitHungry(void)
 void Unit::standardRandomActivity()
 {
 	attachedBuilding=NULL;
-	targetBuilding=NULL;
+	if(targetBuilding!=NULL)
+	{
+		targetBuilding->removeUnitFromHarvesting(this);
+		targetBuilding=NULL;
+	}
 	ownExchangeBuilding=NULL;
 	activity=Unit::ACT_RANDOM;
 	displacement=Unit::DIS_RANDOM;
@@ -619,6 +622,8 @@ void Unit::stopAttachedForBuilding(bool goingInside)
 	
 	attachedBuilding->removeUnitFromWorking(this);
 	attachedBuilding=NULL;
+	if (targetBuilding)
+		targetBuilding->removeUnitFromHarvesting(this);
 	targetBuilding=NULL;
 	ownExchangeBuilding=NULL;
 	assert(needToRecheckMedical);
@@ -723,23 +728,26 @@ void Unit::handleMagic(void)
 
 void Unit::handleMedical(void)
 {
-        /* Make sure explorers try to immediately feed after healing to increase their range. */
-        if ((typeNum == EXPLORER)
-            && (displacement == DIS_EXITING_BUILDING)) {
-          medical=MED_FREE;
-          if ((destinationPurprose == HEAL)
-              && (hungry < ((HUNGRY_MAX * 9) / 10))) {
-            // fprintf (stderr, "forcing explorer hunger: gid: %d, hungry: %d\n", gid, hungry);
-            needToRecheckMedical = 1;
-            medical = MED_HUNGRY;
-            return; }
-          else if ((destinationPurprose == FEED)
-                   && (hp < (((performance[HP]) * 9) / 10))) {
-            // fprintf (stderr, "forcing explorer healing: gid: %d, hp: %d\n", gid, hp);
-            needToRecheckMedical = 1;
-            medical = MED_DAMAGED;
-            return; }}
-
+	/* Make sure explorers try to immediately feed after healing to increase their range. */
+	if ((typeNum == EXPLORER) && (displacement == DIS_EXITING_BUILDING))
+	{
+		medical=MED_FREE;
+		if ((destinationPurprose == HEAL) && (hungry < ((HUNGRY_MAX * 9) / 10)))
+		{
+			// fprintf (stderr, "forcing explorer hunger: gid: %d, hungry: %d\n", gid, hungry);
+			needToRecheckMedical = 1;
+			medical = MED_HUNGRY;
+			return;
+		}
+		else if ((destinationPurprose == FEED) && (hp < (((performance[HP]) * 9) / 10)))
+		{
+			// fprintf (stderr, "forcing explorer healing: gid: %d, hp: %d\n", gid, hp);
+			needToRecheckMedical = 1;
+			medical = MED_DAMAGED;
+			return;
+		}
+	}
+	
 	if ((displacement==DIS_ENTERING_BUILDING) || (displacement==DIS_INSIDE) || (displacement==DIS_EXITING_BUILDING))
 		return;
 	
@@ -770,9 +778,13 @@ void Unit::handleMedical(void)
 				attachedBuilding->removeUnitFromWorking(this);
 				attachedBuilding->removeUnitFromInside(this);
 				attachedBuilding=NULL;
-				targetBuilding=NULL;
 				ownExchangeBuilding=NULL;
 			}
+			if (targetBuilding)
+			{
+				targetBuilding->removeUnitFromHarvesting(this);
+				targetBuilding=NULL;
+			}
 			
 			activity=ACT_RANDOM;
 			validTarget=false;
@@ -870,6 +882,7 @@ void Unit::handleActivity(void)
 	}
 	else if (needToRecheckMedical)
 	{
+		// disconnect from building
 		if (attachedBuilding)
 		{
 			if (verbose)
@@ -877,18 +890,23 @@ void Unit::handleActivity(void)
 			attachedBuilding->removeUnitFromWorking(this);
 			attachedBuilding->removeUnitFromInside(this);
 			attachedBuilding=NULL;
-			targetBuilding=NULL;
 			ownExchangeBuilding=NULL;
 		}
-
+		if (targetBuilding) 
+		{
+			targetBuilding->removeUnitFromHarvesting(this);
+			targetBuilding=NULL;
+		}
+		
 		if (medical==MED_HUNGRY)
 		{
 			Building *b;
 			b=owner->findNearestFood(this);
-                        if (typeNum == EXPLORER) {
-                          // fprintf (stderr, "gid: %d, b: %x\n", gid, b);
-                        }
-
+			if (typeNum == EXPLORER)
+			{
+				// fprintf (stderr, "gid: %d, b: %x\n", gid, b);
+			}
+			
 			if (b!=NULL)
 			{
 				Team *currentTeam=owner;
@@ -1070,6 +1088,7 @@ void Unit::handleDisplacement(void)
 						caryedRessource=destinationPurprose;
 						fprintf(logFile, "[%d] sdp6 destinationPurprose=%d\n", gid, destinationPurprose);
 						
+						targetBuilding->removeUnitFromHarvesting(this);
 						targetBuilding=attachedBuilding;
 						displacement=DIS_GOING_TO_BUILDING;
 						targetX=targetBuilding->getMidX();
@@ -1086,7 +1105,6 @@ void Unit::handleDisplacement(void)
 						printf("guid=(%d) Giving ressource (%d) to building gbid=(%d) old-amount=(%d)\n", gid, destinationPurprose, targetBuilding->gid, targetBuilding->ressources[caryedRessource]);
 					targetBuilding->addRessourceIntoBuilding(caryedRessource);
 					caryedRessource=-1;
-
 				}
 				
 				if (!loopMove && !exchangeReady)
@@ -1106,7 +1124,6 @@ void Unit::handleDisplacement(void)
 						///Find a ressource that the building wants and a location to get it from
 						///The location may be a market, or the harvesting the ressource from the
 						///map.
-						attachedBuilding->update();
 						int needs[MAX_NB_RESSOURCES];
 						attachedBuilding->wishedRessources(needs);
 						int teamNumber=owner->teamNumber;
@@ -1144,12 +1161,12 @@ void Unit::handleDisplacement(void)
 												int buildingDist;
 												if (map->buildingAvailable(*bi, canSwim, posX, posY, &buildingDist))
 												{
-													int value=(buildingDist<<1)/need; // We double the cost to get a ressource in an exchange building.
+													// We increase the cost to get a ressource in an exchange building to reflect the costs to get the ressources to the exchange building.
+													int value=(buildingDist<<1)/need;
 													if (value<minValue)
 													{
 														bestRessource=r;
 														minValue=value;
-
 														ownExchangeBuilding=*bi;
 														targetBuilding=*bi;
 														takeInExchangeBuilding=true;
@@ -1172,6 +1189,7 @@ void Unit::handleDisplacement(void)
 									displacement=DIS_GOING_TO_BUILDING;
 									targetX=targetBuilding->getMidX();
 									targetY=targetBuilding->getMidY();
+									targetBuilding->insertUnitToHarvesting(this);
 									validTarget=true;
 								}
 								else
@@ -1273,7 +1291,6 @@ void Unit::handleDisplacement(void)
 					{
 						hungry=HUNGRY_MAX;
 						fruitCount=attachedBuilding->eatOnce(&fruitMask);
-						//printf("I'm not hungry any more :-)\n");
 						needToRecheckMedical=true;
 					}
 					else if (destinationPurprose==HEAL)
@@ -2089,8 +2106,8 @@ void Unit::handleAction(void)
 			// NOTE : this is a hack : We don't delete the unit on the map
 			// because we have to draw it while it is entering.
 			// owner->map->setUnit(posX, posY, NOUID);
-			posX+=dx;
-			posY+=dy;
+			posX=(posX+dx)&(owner->map->getMaskW());
+			posY=(posY+dy)&(owner->map->getMaskH());
 			directionFromDxDy();
 			selectPreferedMovement();
 			speed=performance[action];
