@@ -122,7 +122,9 @@ public:
 		DIS_HARVESTING=2,
 		
 		DIS_FILLING_BUILDING=4,
-		DIS_EMPTYING_BUILDING=6,
+//NOT USED:
+//		//!Markets can get emptied
+//		DIS_EMPTYING_BUILDING=6,
 		
 		DIS_GOING_TO_FLAG=8,
 		DIS_ATTACKING_AROUND=10,
@@ -217,7 +219,7 @@ public:
 	bool validTarget;
 	Sint32 magicActionTimeout;
 
-	// Timer counts down after last attacked
+	// Timer counts down 240 frames after being attacked
 	Uint8 underAttackTimer;
 
 	// trigger parameters
@@ -239,8 +241,9 @@ public:
 	Sint32 experience;
 	Sint32 experienceLevel;
 	
-	// building attraction handling
+	//! building the Unit is working for
 	Building *attachedBuilding;
+	//! building the Unit is going to
 	Building *targetBuilding;
 	Building *ownExchangeBuilding;
 	Sint32 destinationPurprose;
