@@ -1,10 +1,12 @@
 /*
+  Copyright (C) Bradley Arsenault
+ 
   Copyright (C) 2001-2004 Stephane Magnenat & Luc-Olivier de Charrière
   for any question or comment contact us at <stephane at magnenat dot net> or <NuageBleu at gmail dot com>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
+  the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.
 
   This program is distributed in the hope that it will be useful,
@@ -20,6 +22,8 @@
 #ifndef __UNIT_CONSTS_H
 #define __UNIT_CONSTS_H
 
+#include <string>
+
 enum Abilities
 {
 	STOP_WALK=0,
@@ -56,5 +60,7 @@ const int NB_UNIT_TYPE=3;
 
 const int NB_UNIT_LEVELS=4;
 
+std::string getUnitName(int type);
+
 #endif
  
