@@ -22,18 +22,13 @@
 #include "Toolkit.h"
 #include "FileManager.h"
 #include <iostream>
+#include "YOGConsts.h"
 
 using namespace GAGCore;
 
 YOGServerAdministratorList::YOGServerAdministratorList()
 {
-	InputLineStream* stream = new InputLineStream(Toolkit::getFileManager()->openInputStreamBackend("admins.txt"));
-	while(!stream->isEndOfStream())
-	{
-		std::string name = stream->readLine();
-		admins.insert(name);
-	}
-	delete stream;
+	load();
 }
 
 
@@ -44,3 +39,50 @@ bool YOGServerAdministratorList::isAdministrator(const std::string& playerName)
 		return true;
 	return false;
 }
+
+
+
+void YOGServerAdministratorList::addAdministrator(const std::string& playerName)
+{
+	admins.insert(playerName);
+	save();
+}
+
+
+
+void YOGServerAdministratorList::removeAdministrator(const std::string& playerName)
+{
+	if(admins.find(playerName)!=admins.end())
+		admins.erase(admins.find(playerName));
+	save();
+}
+
+
+
+void YOGServerAdministratorList::save()
+{
+	OutputLineStream* stream = new OutputLineStream(Toolkit::getFileManager()->openOutputStreamBackend(YOG_SERVER_FOLDER+"admins.txt"));
+	for(std::set<std::string>::iterator i=admins.begin(); i!=admins.end(); ++i)
+	{
+		if(*i != "")
+		{
+			stream->writeLine(*i);
+		}
+	}
+	delete stream;
+}
+
+
+
+void YOGServerAdministratorList::load()
+{
+	InputLineStream* stream = new InputLineStream(Toolkit::getFileManager()->openInputStreamBackend(YOG_SERVER_FOLDER+"admins.txt"));
+	while(!stream->isEndOfStream())
+	{
+		std::string name = stream->readLine();
+		admins.insert(name);
+	}
+	delete stream;
+}
+
+
